// ------------------------------------------------------------------------------
//  <autogenerated>
//      This code was generated by a tool.
//      Mono Runtime Version: 2.0.50727.42
// 
//      Changes to this file may cause incorrect behavior and will be lost if 
//      the code is regenerated.
//  </autogenerated>
// ------------------------------------------------------------------------------

namespace YahtzeeSharp {
    
    
    public partial class frmMain {
        
        private Gtk.Action NewGame;
        
        private Gtk.Action open;
        
        private Gtk.Action save;
        
        private Gtk.Action About;
        
        private Gtk.Action quit;
        
        private Gtk.Action add;
        
        private Gtk.Action help;
        
        private Gtk.Action help1;
        
        private Gtk.Action undo;
        
        private Gtk.Action redo;
        
        private Gtk.HBox hbox3;
        
        private Gtk.Alignment alignment1;
        
        private Gtk.VBox vbox2;
        
        private Gtk.HBox hbox1;
        
        private Gtk.Frame frame2;
        
        private Gtk.Alignment GtkAlignment;
        
        private Gtk.Toolbar toolbar2;
        
        private Gtk.Label GtkLabel8;
        
        private Gtk.Frame frame1;
        
        private Gtk.Alignment GtkAlignment8;
        
        private Gtk.VBox vbox3;
        
        private Gtk.Image image2;
        
        private Gtk.Frame frame47;
        
        private Gtk.Alignment GtkAlignment9;
        
        private Gtk.TreeView gvHighScore;
        
        private Gtk.Frame frame5;
        
        private Gtk.VBox vbox4;
        
        private Gtk.Frame pnloop;
        
        private Gtk.Table pnlUpperScore;
        
        private Gtk.Frame frame10;
        
        private Gtk.Image image16;
        
        private Gtk.Frame frame11;
        
        private Gtk.Image image17;
        
        private Gtk.Frame frame12;
        
        private Gtk.Image image4;
        
        private Gtk.Frame frame13;
        
        private Gtk.Image image5;
        
        private Gtk.Frame frame14;
        
        private Gtk.Image image6;
        
        private Gtk.Frame frame15;
        
        private Gtk.Image image7;
        
        private Gtk.Frame frame16;
        
        private Gtk.Image image8;
        
        private Gtk.Frame frame17;
        
        private Gtk.Image image9;
        
        private Gtk.Frame frame18;
        
        private Gtk.Image image10;
        
        private Gtk.Frame frame19;
        
        private Gtk.Image image11;
        
        private Gtk.Frame frame20;
        
        private Gtk.Image image12;
        
        private Gtk.Frame frame21;
        
        private Gtk.Image image19;
        
        private Gtk.Frame frame22;
        
        private Gtk.Image image20;
        
        private Gtk.Frame frame23;
        
        private Gtk.Image image21;
        
        private Gtk.Frame frame24;
        
        private Gtk.Image image22;
        
        private Gtk.Frame frame25;
        
        private Gtk.Image image23;
        
        private Gtk.Frame frame26;
        
        private Gtk.Image image24;
        
        private Gtk.Frame frame27;
        
        private Gtk.Image image25;
        
        private Gtk.Frame frame28;
        
        private Gtk.Image image26;
        
        private Gtk.Frame frame4;
        
        private Gtk.Image image1;
        
        private Gtk.Frame frame54;
        
        private Gtk.Image image54;
        
        private Gtk.Frame frame6;
        
        private Gtk.Image image18;
        
        private Gtk.Frame frame7;
        
        private Gtk.Image image13;
        
        private Gtk.Frame frame8;
        
        private Gtk.Image image3;
        
        private Gtk.Frame frame9;
        
        private Gtk.Image image15;
        
        private Gtk.Frame r0c1;
        
        private Gtk.Button btnr0c1;
        
        private Gtk.Frame r0c2;
        
        private Gtk.Button btnr0c2;
        
        private Gtk.Frame r0c3;
        
        private Gtk.Button btnr0c3;
        
        private Gtk.Frame r0c4;
        
        private Gtk.Button btnr0c4;
        
        private Gtk.Frame r0c5;
        
        private Gtk.Button btnr0c5;
        
        private Gtk.Frame r1c1;
        
        private Gtk.Button btnr1c1;
        
        private Gtk.Frame r1c2;
        
        private Gtk.Button btnr1c2;
        
        private Gtk.Frame r1c3;
        
        private Gtk.Button btnr1c3;
        
        private Gtk.Frame r1c4;
        
        private Gtk.Button btnr1c4;
        
        private Gtk.Frame r1c5;
        
        private Gtk.Button btnr1c5;
        
        private Gtk.Frame r2c1;
        
        private Gtk.Button btnr2c1;
        
        private Gtk.Frame r2c2;
        
        private Gtk.Button btnr2c2;
        
        private Gtk.Frame r2c3;
        
        private Gtk.Button btnr2c3;
        
        private Gtk.Frame r2c4;
        
        private Gtk.Button btnr2c4;
        
        private Gtk.Frame r2c5;
        
        private Gtk.Button btnr2c5;
        
        private Gtk.Frame r3c1;
        
        private Gtk.Button btnr3c1;
        
        private Gtk.Frame r3c2;
        
        private Gtk.Button btnr3c2;
        
        private Gtk.Frame r3c3;
        
        private Gtk.Button btnr3c3;
        
        private Gtk.Frame r3c4;
        
        private Gtk.Button btnr3c4;
        
        private Gtk.Frame r3c5;
        
        private Gtk.Button btnr3c5;
        
        private Gtk.Frame r4c1;
        
        private Gtk.Button btnr4c1;
        
        private Gtk.Frame r4c2;
        
        private Gtk.Button btnr4c2;
        
        private Gtk.Frame r4c3;
        
        private Gtk.Button btnr4c3;
        
        private Gtk.Frame r4c4;
        
        private Gtk.Button btnr4c4;
        
        private Gtk.Frame r4c5;
        
        private Gtk.Button btnr4c5;
        
        private Gtk.Frame r5c1;
        
        private Gtk.Button btnr5c1;
        
        private Gtk.Frame r5c2;
        
        private Gtk.Button btnr5c2;
        
        private Gtk.Frame r5c3;
        
        private Gtk.Button btnr5c3;
        
        private Gtk.Frame r5c4;
        
        private Gtk.Button btnr5c4;
        
        private Gtk.Frame r5c5;
        
        private Gtk.Button btnr5c5;
        
        private Gtk.Frame r6c1;
        
        private Gtk.Label btnr6c1;
        
        private Gtk.Frame r6c2;
        
        private Gtk.Label btnr6c2;
        
        private Gtk.Frame r6c3;
        
        private Gtk.Label btnr6c3;
        
        private Gtk.Frame r6c4;
        
        private Gtk.Label btnr6c4;
        
        private Gtk.Frame r6c5;
        
        private Gtk.Label btnr6c5;
        
        private Gtk.Frame r7c1;
        
        private Gtk.Label btnr7c1;
        
        private Gtk.Frame r7c2;
        
        private Gtk.Label btnr7c2;
        
        private Gtk.Frame r7c3;
        
        private Gtk.Label btnr7c3;
        
        private Gtk.Frame r7c4;
        
        private Gtk.Label btnr7c4;
        
        private Gtk.Frame r7c5;
        
        private Gtk.Label btnr7c5;
        
        private Gtk.Frame r8c1;
        
        private Gtk.Label btnr8c1;
        
        private Gtk.Frame r8c2;
        
        private Gtk.Label btnr8c2;
        
        private Gtk.Frame r8c3;
        
        private Gtk.Label btnr8c3;
        
        private Gtk.Frame r8c4;
        
        private Gtk.Label btnr8c4;
        
        private Gtk.Frame r8c5;
        
        private Gtk.Label btnr8c5;
        
        private Gtk.Image image27;
        
        private Gtk.Frame pnlopps2;
        
        private Gtk.Table pnlLowerScore;
        
        private Gtk.Frame frame148;
        
        private Gtk.Image image52;
        
        private Gtk.Frame frame153;
        
        private Gtk.Image image30;
        
        private Gtk.Frame frame29;
        
        private Gtk.Image image45;
        
        private Gtk.Frame frame30;
        
        private Gtk.Image image29;
        
        private Gtk.Frame frame31;
        
        private Gtk.Image image53;
        
        private Gtk.Frame frame32;
        
        private Gtk.Image image31;
        
        private Gtk.Frame frame33;
        
        private Gtk.Image image32;
        
        private Gtk.Frame frame34;
        
        private Gtk.Image image33;
        
        private Gtk.Frame frame35;
        
        private Gtk.Image image34;
        
        private Gtk.Frame frame36;
        
        private Gtk.Image image35;
        
        private Gtk.Frame frame37;
        
        private Gtk.Image image36;
        
        private Gtk.Frame frame38;
        
        private Gtk.Image image37;
        
        private Gtk.Frame frame39;
        
        private Gtk.Image image14;
        
        private Gtk.Frame frame40;
        
        private Gtk.Image image38;
        
        private Gtk.Frame frame41;
        
        private Gtk.Image image55;
        
        private Gtk.Frame frame42;
        
        private Gtk.Image image40;
        
        private Gtk.Frame frame43;
        
        private Gtk.Image image41;
        
        private Gtk.Frame frame44;
        
        private Gtk.Image image42;
        
        private Gtk.Frame frame45;
        
        private Gtk.Image image43;
        
        private Gtk.Frame frame46;
        
        private Gtk.Image image44;
        
        private Gtk.Frame frame52;
        
        private Gtk.Image image39;
        
        private Gtk.Frame frame53;
        
        private Gtk.Image image28;
        
        private Gtk.HSeparator hseparator1;
        
        private Gtk.HSeparator hseparator4;
        
        private Gtk.HSeparator hseparator5;
        
        private Gtk.HSeparator hseparator6;
        
        private Gtk.HSeparator hseparator7;
        
        private Gtk.HSeparator hseparator8;
        
        private Gtk.HSeparator hseparator9;
        
        private Gtk.Frame r10c1;
        
        private Gtk.Button btnr10c1;
        
        private Gtk.Frame r10c2;
        
        private Gtk.Button btnr10c2;
        
        private Gtk.Frame r10c3;
        
        private Gtk.Button btnr10c3;
        
        private Gtk.Frame r10c4;
        
        private Gtk.Button btnr10c4;
        
        private Gtk.Frame r10c5;
        
        private Gtk.Button btnr10c5;
        
        private Gtk.Frame r11c1;
        
        private Gtk.Button btnr11c1;
        
        private Gtk.Frame r11c2;
        
        private Gtk.Button btnr11c2;
        
        private Gtk.Frame r11c3;
        
        private Gtk.Button btnr11c3;
        
        private Gtk.Frame r11c4;
        
        private Gtk.Button btnr11c4;
        
        private Gtk.Frame r11c5;
        
        private Gtk.Button btnr11c5;
        
        private Gtk.Frame r12c1;
        
        private Gtk.Button btnr12c1;
        
        private Gtk.Frame r12c2;
        
        private Gtk.Button btnr12c2;
        
        private Gtk.Frame r12c3;
        
        private Gtk.Button btnr12c3;
        
        private Gtk.Frame r12c4;
        
        private Gtk.Button btnr12c4;
        
        private Gtk.Frame r12c5;
        
        private Gtk.Button btnr12c5;
        
        private Gtk.Frame r13c1;
        
        private Gtk.Button btnr13c1;
        
        private Gtk.Frame r13c2;
        
        private Gtk.Button btnr13c2;
        
        private Gtk.Frame r13c3;
        
        private Gtk.Button btnr13c3;
        
        private Gtk.Frame r13c4;
        
        private Gtk.Button btnr13c4;
        
        private Gtk.Frame r13c5;
        
        private Gtk.Button btnr13c5;
        
        private Gtk.Frame r14c1;
        
        private Gtk.Button btnr14c1;
        
        private Gtk.Frame r14c2;
        
        private Gtk.Button btnr14c2;
        
        private Gtk.Frame r14c3;
        
        private Gtk.Button btnr14c3;
        
        private Gtk.Frame r14c4;
        
        private Gtk.Button btnr14c4;
        
        private Gtk.Frame r14c5;
        
        private Gtk.Button btnr14c5;
        
        private Gtk.Frame r15c1;
        
        private Gtk.Button btnr15c1;
        
        private Gtk.Frame r15c2;
        
        private Gtk.Button btnr15c2;
        
        private Gtk.Frame r15c3;
        
        private Gtk.Button btnr15c3;
        
        private Gtk.Frame r15c4;
        
        private Gtk.Button btnr15c4;
        
        private Gtk.Frame r15c5;
        
        private Gtk.Button btnr15c5;
        
        private Gtk.Frame r16c1;
        
        private Gtk.Button btnr16c1;
        
        private Gtk.Frame r16c2;
        
        private Gtk.Button btnr16c2;
        
        private Gtk.Frame r16c3;
        
        private Gtk.Button btnr16c3;
        
        private Gtk.Frame r16c4;
        
        private Gtk.Button btnr16c4;
        
        private Gtk.Frame r16c5;
        
        private Gtk.Button btnr16c5;
        
        private Gtk.Frame r17c1;
        
        private Gtk.Label btnr17c1;
        
        private Gtk.Frame r17c2;
        
        private Gtk.Label btnr17c2;
        
        private Gtk.Frame r17c3;
        
        private Gtk.Label btnr17c3;
        
        private Gtk.Frame r17c4;
        
        private Gtk.Label btnr17c4;
        
        private Gtk.Frame r17c5;
        
        private Gtk.Label btnr17c5;
        
        private Gtk.Frame r18c1;
        
        private Gtk.Label rbtn18c1;
        
        private Gtk.Frame r18c2;
        
        private Gtk.Label btnr18c2;
        
        private Gtk.Frame r18c3;
        
        private Gtk.Label btnr18c3;
        
        private Gtk.Frame r18c4;
        
        private Gtk.Label btnr18c4;
        
        private Gtk.Frame r18c5;
        
        private Gtk.Label btnr18c5;
        
        private Gtk.Frame r19c1;
        
        private Gtk.Label btnr19c1;
        
        private Gtk.Frame r19c2;
        
        private Gtk.Label btnr19c2;
        
        private Gtk.Frame r19c3;
        
        private Gtk.Label btnr19c3;
        
        private Gtk.Frame r19c4;
        
        private Gtk.Label btnr19c4;
        
        private Gtk.Frame r19c5;
        
        private Gtk.Label btnr19c5;
        
        private Gtk.Frame r9c1;
        
        private Gtk.Button btnr9c1;
        
        private Gtk.Frame r9c2;
        
        private Gtk.Button btnr9c2;
        
        private Gtk.Frame r9c3;
        
        private Gtk.Button btnr9c3;
        
        private Gtk.Frame r9c4;
        
        private Gtk.Button btnr9c4;
        
        private Gtk.Frame r9c5;
        
        private Gtk.Button btnr9c5;
        
        private Gtk.Frame frame3;
        
        private Gtk.Alignment GtkAlignment10;
        
        private Gtk.VBox vbox1;
        
        private Gtk.Frame frame145;
        
        private Gtk.VBox vbox5;
        
        private Gtk.Label label1;
        
        private Gtk.Alignment alignment2;
        
        private Gtk.Entry txtPlayerName;
        
        private Gtk.Table tblDice;
        
        private Gtk.Button cmdDice1;
        
        private Gtk.Image Dice1;
        
        private Gtk.Button cmdDice2;
        
        private Gtk.Image Dice2;
        
        private Gtk.Button cmdDice3;
        
        private Gtk.Image Dice3;
        
        private Gtk.Button cmdDice4;
        
        private Gtk.Image Dice4;
        
        private Gtk.Button cmdDice5;
        
        private Gtk.Image Dice5;
        
        private Gtk.Label lblHold1;
        
        private Gtk.Label lblHold2;
        
        private Gtk.Label lblHold3;
        
        private Gtk.Label lblHold4;
        
        private Gtk.Label lblHold5;
        
        private Gtk.HButtonBox hbuttonbox1;
        
        private Gtk.Button btnRoll;
        
        private Gtk.HBox hbox2;
        
        private Gtk.Label label2;
        
        private Gtk.Label lblRollNumber;
        
        private Gtk.Frame frame48;
        
        private Gtk.Alignment GtkAlignment11;
        
        private Gtk.ScrolledWindow GtkScrolledWindow;
        
        private Gtk.TreeView gvResults;
        
        protected virtual void Build() {
            Stetic.Gui.Initialize(this);
            // Widget YahtzeeSharp.frmMain
            Gtk.UIManager w1 = new Gtk.UIManager();
            Gtk.ActionGroup w2 = new Gtk.ActionGroup("Default");
            this.NewGame = new Gtk.Action("NewGame", Mono.Unix.Catalog.GetString("New Game"), null, "gtk-new");
            this.NewGame.ShortLabel = "New Game";
            w2.Add(this.NewGame, null);
            this.open = new Gtk.Action("open", null, null, "gtk-open");
            w2.Add(this.open, null);
            this.save = new Gtk.Action("save", null, null, "gtk-save");
            this.save.Sensitive = false;
            w2.Add(this.save, null);
            this.About = new Gtk.Action("About", Mono.Unix.Catalog.GetString("About"), null, "gtk-dialog-question");
            this.About.ShortLabel = "About";
            w2.Add(this.About, null);
            this.quit = new Gtk.Action("quit", null, null, "gtk-quit");
            w2.Add(this.quit, null);
            this.add = new Gtk.Action("add", null, null, "gtk-add");
            w2.Add(this.add, null);
            this.help = new Gtk.Action("help", null, null, "gtk-help");
            w2.Add(this.help, null);
            this.help1 = new Gtk.Action("help1", null, null, "gtk-help");
            w2.Add(this.help1, null);
            this.undo = new Gtk.Action("undo", null, null, "gtk-undo");
            this.undo.Sensitive = false;
            w2.Add(this.undo, null);
            this.redo = new Gtk.Action("redo", null, null, "gtk-redo");
            this.redo.Sensitive = false;
            w2.Add(this.redo, null);
            w1.InsertActionGroup(w2, 0);
            this.AddAccelGroup(w1.AccelGroup);
            this.WidthRequest = 995;
            this.HeightRequest = 725;
            this.Name = "YahtzeeSharp.frmMain";
            this.Title = Mono.Unix.Catalog.GetString("Yahtzee Sharp");
            this.Icon = Gdk.Pixbuf.LoadFromResource("YSlogo.png");
            this.WindowPosition = ((Gtk.WindowPosition)(1));
            this.AllowShrink = true;
            this.DefaultWidth = 995;
            this.DefaultHeight = 725;
            // Container child YahtzeeSharp.frmMain.Gtk.Container+ContainerChild
            this.hbox3 = new Gtk.HBox();
            this.hbox3.Name = "hbox3";
            // Container child hbox3.Gtk.Box+BoxChild
            this.alignment1 = new Gtk.Alignment(0.5F, 0.5F, 0.5F, 1F);
            this.alignment1.Name = "alignment1";
            this.alignment1.LeftPadding = ((uint)(2));
            this.alignment1.TopPadding = ((uint)(2));
            this.alignment1.RightPadding = ((uint)(2));
            this.alignment1.BottomPadding = ((uint)(2));
            // Container child alignment1.Gtk.Container+ContainerChild
            this.vbox2 = new Gtk.VBox();
            this.vbox2.Name = "vbox2";
            // Container child vbox2.Gtk.Box+BoxChild
            this.hbox1 = new Gtk.HBox();
            this.hbox1.Name = "hbox1";
            this.hbox1.Spacing = 4;
            this.hbox1.BorderWidth = ((uint)(5));
            // Container child hbox1.Gtk.Box+BoxChild
            this.frame2 = new Gtk.Frame();
            this.frame2.Name = "frame2";
            this.frame2.ShadowType = ((Gtk.ShadowType)(1));
            // Container child frame2.Gtk.Container+ContainerChild
            this.GtkAlignment = new Gtk.Alignment(0.5F, 0.5F, 1F, 1F);
            this.GtkAlignment.Name = "GtkAlignment";
            // Container child GtkAlignment.Gtk.Container+ContainerChild
            w1.AddUiFromString("<ui><toolbar name='toolbar2'><toolitem action='NewGame'/><toolitem action='open'/><toolitem action='save'/><separator/><toolitem action='undo'/><toolitem action='redo'/><separator/><toolitem action='About'/><toolitem action='quit'/></toolbar></ui>");
            this.toolbar2 = ((Gtk.Toolbar)(w1.GetWidget("/toolbar2")));
            this.toolbar2.Name = "toolbar2";
            this.toolbar2.Orientation = ((Gtk.Orientation)(1));
            this.toolbar2.ShowArrow = false;
            this.toolbar2.ToolbarStyle = ((Gtk.ToolbarStyle)(2));
            this.GtkAlignment.Add(this.toolbar2);
            this.frame2.Add(this.GtkAlignment);
            this.GtkLabel8 = new Gtk.Label();
            this.GtkLabel8.Name = "GtkLabel8";
            this.GtkLabel8.LabelProp = Mono.Unix.Catalog.GetString("<b>Menu</b>");
            this.GtkLabel8.UseMarkup = true;
            this.GtkLabel8.Justify = ((Gtk.Justification)(2));
            this.GtkLabel8.SingleLineMode = true;
            this.frame2.LabelWidget = this.GtkLabel8;
            this.hbox1.Add(this.frame2);
            Gtk.Box.BoxChild w5 = ((Gtk.Box.BoxChild)(this.hbox1[this.frame2]));
            w5.Position = 0;
            w5.Expand = false;
            w5.Fill = false;
            // Container child hbox1.Gtk.Box+BoxChild
            this.frame1 = new Gtk.Frame();
            this.frame1.Name = "frame1";
            this.frame1.ShadowType = ((Gtk.ShadowType)(1));
            // Container child frame1.Gtk.Container+ContainerChild
            this.GtkAlignment8 = new Gtk.Alignment(0.5F, 0.5F, 0.5F, 1F);
            this.GtkAlignment8.Name = "GtkAlignment8";
            this.GtkAlignment8.LeftPadding = ((uint)(2));
            this.GtkAlignment8.TopPadding = ((uint)(5));
            this.GtkAlignment8.RightPadding = ((uint)(2));
            // Container child GtkAlignment8.Gtk.Container+ContainerChild
            this.vbox3 = new Gtk.VBox();
            this.vbox3.Name = "vbox3";
            this.vbox3.Spacing = 10;
            // Container child vbox3.Gtk.Box+BoxChild
            this.image2 = new Gtk.Image();
            this.image2.Name = "image2";
            this.image2.Pixbuf = Gdk.Pixbuf.LoadFromResource("Logo.png");
            this.vbox3.Add(this.image2);
            Gtk.Box.BoxChild w6 = ((Gtk.Box.BoxChild)(this.vbox3[this.image2]));
            w6.Position = 0;
            w6.Expand = false;
            w6.Fill = false;
            // Container child vbox3.Gtk.Box+BoxChild
            this.frame47 = new Gtk.Frame();
            this.frame47.Name = "frame47";
            this.frame47.ShadowType = ((Gtk.ShadowType)(1));
            // Container child frame47.Gtk.Container+ContainerChild
            this.GtkAlignment9 = new Gtk.Alignment(0F, 0F, 1F, 1F);
            this.GtkAlignment9.Name = "GtkAlignment9";
            // Container child GtkAlignment9.Gtk.Container+ContainerChild
            this.gvHighScore = new Gtk.TreeView();
            this.gvHighScore.CanFocus = true;
            this.gvHighScore.Name = "gvHighScore";
            this.gvHighScore.EnableSearch = false;
            this.gvHighScore.RulesHint = true;
            this.gvHighScore.SearchColumn = 2;
            this.GtkAlignment9.Add(this.gvHighScore);
            this.frame47.Add(this.GtkAlignment9);
            this.vbox3.Add(this.frame47);
            Gtk.Box.BoxChild w9 = ((Gtk.Box.BoxChild)(this.vbox3[this.frame47]));
            w9.Position = 1;
            this.GtkAlignment8.Add(this.vbox3);
            this.frame1.Add(this.GtkAlignment8);
            this.hbox1.Add(this.frame1);
            Gtk.Box.BoxChild w12 = ((Gtk.Box.BoxChild)(this.hbox1[this.frame1]));
            w12.Position = 1;
            w12.Expand = false;
            w12.Fill = false;
            w12.Padding = ((uint)(3));
            // Container child hbox1.Gtk.Box+BoxChild
            this.frame5 = new Gtk.Frame();
            this.frame5.Name = "frame5";
            // Container child frame5.Gtk.Container+ContainerChild
            this.vbox4 = new Gtk.VBox();
            this.vbox4.Name = "vbox4";
            // Container child vbox4.Gtk.Box+BoxChild
            this.pnloop = new Gtk.Frame();
            this.pnloop.Name = "pnloop";
            // Container child pnloop.Gtk.Container+ContainerChild
            this.pnlUpperScore = new Gtk.Table(((uint)(10)), ((uint)(7)), false);
            this.pnlUpperScore.Name = "pnlUpperScore";
            this.pnlUpperScore.RowSpacing = ((uint)(6));
            this.pnlUpperScore.ColumnSpacing = ((uint)(6));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame10 = new Gtk.Frame();
            this.frame10.Name = "frame10";
            // Container child frame10.Gtk.Container+ContainerChild
            this.image16 = new Gtk.Image();
            this.image16.Name = "image16";
            this.image16.Pixbuf = Gdk.Pixbuf.LoadFromResource("h5.png");
            this.frame10.Add(this.image16);
            this.pnlUpperScore.Add(this.frame10);
            Gtk.Table.TableChild w14 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame10]));
            w14.LeftAttach = ((uint)(4));
            w14.RightAttach = ((uint)(5));
            w14.XOptions = ((Gtk.AttachOptions)(4));
            w14.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame11 = new Gtk.Frame();
            this.frame11.Name = "frame11";
            // Container child frame11.Gtk.Container+ContainerChild
            this.image17 = new Gtk.Image();
            this.image17.Name = "image17";
            this.image17.Pixbuf = Gdk.Pixbuf.LoadFromResource("h6.png");
            this.frame11.Add(this.image17);
            this.pnlUpperScore.Add(this.frame11);
            Gtk.Table.TableChild w16 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame11]));
            w16.LeftAttach = ((uint)(5));
            w16.RightAttach = ((uint)(6));
            w16.XOptions = ((Gtk.AttachOptions)(4));
            w16.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame12 = new Gtk.Frame();
            this.frame12.Name = "frame12";
            // Container child frame12.Gtk.Container+ContainerChild
            this.image4 = new Gtk.Image();
            this.image4.Name = "image4";
            this.image4.Pixbuf = Gdk.Pixbuf.LoadFromResource("dd2.png");
            this.frame12.Add(this.image4);
            this.pnlUpperScore.Add(this.frame12);
            Gtk.Table.TableChild w18 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame12]));
            w18.TopAttach = ((uint)(2));
            w18.BottomAttach = ((uint)(3));
            w18.XOptions = ((Gtk.AttachOptions)(4));
            w18.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame13 = new Gtk.Frame();
            this.frame13.Name = "frame13";
            // Container child frame13.Gtk.Container+ContainerChild
            this.image5 = new Gtk.Image();
            this.image5.Name = "image5";
            this.image5.Pixbuf = Gdk.Pixbuf.LoadFromResource("dd3.png");
            this.frame13.Add(this.image5);
            this.pnlUpperScore.Add(this.frame13);
            Gtk.Table.TableChild w20 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame13]));
            w20.TopAttach = ((uint)(3));
            w20.BottomAttach = ((uint)(4));
            w20.XOptions = ((Gtk.AttachOptions)(4));
            w20.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame14 = new Gtk.Frame();
            this.frame14.Name = "frame14";
            // Container child frame14.Gtk.Container+ContainerChild
            this.image6 = new Gtk.Image();
            this.image6.Name = "image6";
            this.image6.Pixbuf = Gdk.Pixbuf.LoadFromResource("dd4.png");
            this.frame14.Add(this.image6);
            this.pnlUpperScore.Add(this.frame14);
            Gtk.Table.TableChild w22 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame14]));
            w22.TopAttach = ((uint)(4));
            w22.BottomAttach = ((uint)(5));
            w22.XOptions = ((Gtk.AttachOptions)(4));
            w22.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame15 = new Gtk.Frame();
            this.frame15.Name = "frame15";
            // Container child frame15.Gtk.Container+ContainerChild
            this.image7 = new Gtk.Image();
            this.image7.Name = "image7";
            this.image7.Pixbuf = Gdk.Pixbuf.LoadFromResource("dd5.png");
            this.frame15.Add(this.image7);
            this.pnlUpperScore.Add(this.frame15);
            Gtk.Table.TableChild w24 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame15]));
            w24.TopAttach = ((uint)(5));
            w24.BottomAttach = ((uint)(6));
            w24.XOptions = ((Gtk.AttachOptions)(4));
            w24.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame16 = new Gtk.Frame();
            this.frame16.Name = "frame16";
            // Container child frame16.Gtk.Container+ContainerChild
            this.image8 = new Gtk.Image();
            this.image8.Name = "image8";
            this.image8.Pixbuf = Gdk.Pixbuf.LoadFromResource("dd6.png");
            this.frame16.Add(this.image8);
            this.pnlUpperScore.Add(this.frame16);
            Gtk.Table.TableChild w26 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame16]));
            w26.TopAttach = ((uint)(6));
            w26.BottomAttach = ((uint)(7));
            w26.XOptions = ((Gtk.AttachOptions)(4));
            w26.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame17 = new Gtk.Frame();
            this.frame17.Name = "frame17";
            // Container child frame17.Gtk.Container+ContainerChild
            this.image9 = new Gtk.Image();
            this.image9.Name = "image9";
            this.image9.Pixbuf = Gdk.Pixbuf.LoadFromResource("c8.png");
            this.frame17.Add(this.image9);
            this.pnlUpperScore.Add(this.frame17);
            Gtk.Table.TableChild w28 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame17]));
            w28.TopAttach = ((uint)(7));
            w28.BottomAttach = ((uint)(8));
            w28.XOptions = ((Gtk.AttachOptions)(4));
            w28.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame18 = new Gtk.Frame();
            this.frame18.Name = "frame18";
            // Container child frame18.Gtk.Container+ContainerChild
            this.image10 = new Gtk.Image();
            this.image10.Name = "image10";
            this.image10.Pixbuf = Gdk.Pixbuf.LoadFromResource("c9.png");
            this.frame18.Add(this.image10);
            this.pnlUpperScore.Add(this.frame18);
            Gtk.Table.TableChild w30 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame18]));
            w30.TopAttach = ((uint)(8));
            w30.BottomAttach = ((uint)(9));
            w30.XOptions = ((Gtk.AttachOptions)(4));
            w30.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame19 = new Gtk.Frame();
            this.frame19.Name = "frame19";
            // Container child frame19.Gtk.Container+ContainerChild
            this.image11 = new Gtk.Image();
            this.image11.Name = "image11";
            this.image11.Pixbuf = Gdk.Pixbuf.LoadFromResource("totalUpper.png");
            this.frame19.Add(this.image11);
            this.pnlUpperScore.Add(this.frame19);
            Gtk.Table.TableChild w32 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame19]));
            w32.TopAttach = ((uint)(9));
            w32.BottomAttach = ((uint)(10));
            w32.XOptions = ((Gtk.AttachOptions)(4));
            w32.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame20 = new Gtk.Frame();
            this.frame20.Name = "frame20";
            // Container child frame20.Gtk.Container+ContainerChild
            this.image12 = new Gtk.Image();
            this.image12.Name = "image12";
            this.image12.Pixbuf = Gdk.Pixbuf.LoadFromResource("Aces.png");
            this.frame20.Add(this.image12);
            this.pnlUpperScore.Add(this.frame20);
            Gtk.Table.TableChild w34 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame20]));
            w34.TopAttach = ((uint)(1));
            w34.BottomAttach = ((uint)(2));
            w34.LeftAttach = ((uint)(1));
            w34.RightAttach = ((uint)(2));
            w34.XOptions = ((Gtk.AttachOptions)(4));
            w34.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame21 = new Gtk.Frame();
            this.frame21.Name = "frame21";
            // Container child frame21.Gtk.Container+ContainerChild
            this.image19 = new Gtk.Image();
            this.image19.Name = "image19";
            this.image19.Pixbuf = Gdk.Pixbuf.LoadFromResource("Twos.png");
            this.frame21.Add(this.image19);
            this.pnlUpperScore.Add(this.frame21);
            Gtk.Table.TableChild w36 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame21]));
            w36.TopAttach = ((uint)(2));
            w36.BottomAttach = ((uint)(3));
            w36.LeftAttach = ((uint)(1));
            w36.RightAttach = ((uint)(2));
            w36.XOptions = ((Gtk.AttachOptions)(4));
            w36.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame22 = new Gtk.Frame();
            this.frame22.Name = "frame22";
            // Container child frame22.Gtk.Container+ContainerChild
            this.image20 = new Gtk.Image();
            this.image20.Name = "image20";
            this.image20.Pixbuf = Gdk.Pixbuf.LoadFromResource("Threes.png");
            this.frame22.Add(this.image20);
            this.pnlUpperScore.Add(this.frame22);
            Gtk.Table.TableChild w38 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame22]));
            w38.TopAttach = ((uint)(3));
            w38.BottomAttach = ((uint)(4));
            w38.LeftAttach = ((uint)(1));
            w38.RightAttach = ((uint)(2));
            w38.XOptions = ((Gtk.AttachOptions)(4));
            w38.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame23 = new Gtk.Frame();
            this.frame23.Name = "frame23";
            // Container child frame23.Gtk.Container+ContainerChild
            this.image21 = new Gtk.Image();
            this.image21.Name = "image21";
            this.image21.Pixbuf = Gdk.Pixbuf.LoadFromResource("Fours.png");
            this.frame23.Add(this.image21);
            this.pnlUpperScore.Add(this.frame23);
            Gtk.Table.TableChild w40 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame23]));
            w40.TopAttach = ((uint)(4));
            w40.BottomAttach = ((uint)(5));
            w40.LeftAttach = ((uint)(1));
            w40.RightAttach = ((uint)(2));
            w40.XOptions = ((Gtk.AttachOptions)(4));
            w40.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame24 = new Gtk.Frame();
            this.frame24.Name = "frame24";
            // Container child frame24.Gtk.Container+ContainerChild
            this.image22 = new Gtk.Image();
            this.image22.Name = "image22";
            this.image22.Pixbuf = Gdk.Pixbuf.LoadFromResource("Fives.png");
            this.frame24.Add(this.image22);
            this.pnlUpperScore.Add(this.frame24);
            Gtk.Table.TableChild w42 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame24]));
            w42.TopAttach = ((uint)(5));
            w42.BottomAttach = ((uint)(6));
            w42.LeftAttach = ((uint)(1));
            w42.RightAttach = ((uint)(2));
            w42.XOptions = ((Gtk.AttachOptions)(4));
            w42.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame25 = new Gtk.Frame();
            this.frame25.Name = "frame25";
            // Container child frame25.Gtk.Container+ContainerChild
            this.image23 = new Gtk.Image();
            this.image23.Name = "image23";
            this.image23.Pixbuf = Gdk.Pixbuf.LoadFromResource("Sixes.png");
            this.frame25.Add(this.image23);
            this.pnlUpperScore.Add(this.frame25);
            Gtk.Table.TableChild w44 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame25]));
            w44.TopAttach = ((uint)(6));
            w44.BottomAttach = ((uint)(7));
            w44.LeftAttach = ((uint)(1));
            w44.RightAttach = ((uint)(2));
            w44.XOptions = ((Gtk.AttachOptions)(4));
            w44.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame26 = new Gtk.Frame();
            this.frame26.Name = "frame26";
            // Container child frame26.Gtk.Container+ContainerChild
            this.image24 = new Gtk.Image();
            this.image24.Name = "image24";
            this.image24.Pixbuf = Gdk.Pixbuf.LoadFromResource("arrow_temp.png");
            this.frame26.Add(this.image24);
            this.pnlUpperScore.Add(this.frame26);
            Gtk.Table.TableChild w46 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame26]));
            w46.TopAttach = ((uint)(7));
            w46.BottomAttach = ((uint)(8));
            w46.LeftAttach = ((uint)(1));
            w46.RightAttach = ((uint)(2));
            w46.XOptions = ((Gtk.AttachOptions)(4));
            w46.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame27 = new Gtk.Frame();
            this.frame27.Name = "frame27";
            // Container child frame27.Gtk.Container+ContainerChild
            this.image25 = new Gtk.Image();
            this.image25.Name = "image25";
            this.image25.Pixbuf = Gdk.Pixbuf.LoadFromResource("SCORE2.png");
            this.frame27.Add(this.image25);
            this.pnlUpperScore.Add(this.frame27);
            Gtk.Table.TableChild w48 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame27]));
            w48.TopAttach = ((uint)(8));
            w48.BottomAttach = ((uint)(9));
            w48.LeftAttach = ((uint)(1));
            w48.RightAttach = ((uint)(2));
            w48.XOptions = ((Gtk.AttachOptions)(4));
            w48.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame28 = new Gtk.Frame();
            this.frame28.Name = "frame28";
            // Container child frame28.Gtk.Container+ContainerChild
            this.image26 = new Gtk.Image();
            this.image26.Name = "image26";
            this.image26.Pixbuf = Gdk.Pixbuf.LoadFromResource("arrow_temp.png");
            this.frame28.Add(this.image26);
            this.pnlUpperScore.Add(this.frame28);
            Gtk.Table.TableChild w50 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame28]));
            w50.TopAttach = ((uint)(9));
            w50.BottomAttach = ((uint)(10));
            w50.LeftAttach = ((uint)(1));
            w50.RightAttach = ((uint)(2));
            w50.XOptions = ((Gtk.AttachOptions)(4));
            w50.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame4 = new Gtk.Frame();
            this.frame4.Name = "frame4";
            // Container child frame4.Gtk.Container+ContainerChild
            this.image1 = new Gtk.Image();
            this.image1.Name = "image1";
            this.image1.Pixbuf = Gdk.Pixbuf.LoadFromResource("h1.png");
            this.frame4.Add(this.image1);
            this.pnlUpperScore.Add(this.frame4);
            Gtk.Table.TableChild w52 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame4]));
            w52.XOptions = ((Gtk.AttachOptions)(4));
            w52.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame54 = new Gtk.Frame();
            this.frame54.Name = "frame54";
            // Container child frame54.Gtk.Container+ContainerChild
            this.image54 = new Gtk.Image();
            this.image54.Name = "image54";
            this.image54.Pixbuf = Gdk.Pixbuf.LoadFromResource("h3.png");
            this.frame54.Add(this.image54);
            this.pnlUpperScore.Add(this.frame54);
            Gtk.Table.TableChild w54 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame54]));
            w54.LeftAttach = ((uint)(2));
            w54.RightAttach = ((uint)(3));
            w54.XOptions = ((Gtk.AttachOptions)(4));
            w54.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame6 = new Gtk.Frame();
            this.frame6.Name = "frame6";
            // Container child frame6.Gtk.Container+ContainerChild
            this.image18 = new Gtk.Image();
            this.image18.Name = "image18";
            this.image18.Pixbuf = Gdk.Pixbuf.LoadFromResource("h7.png");
            this.frame6.Add(this.image18);
            this.pnlUpperScore.Add(this.frame6);
            Gtk.Table.TableChild w56 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame6]));
            w56.LeftAttach = ((uint)(6));
            w56.RightAttach = ((uint)(7));
            w56.XOptions = ((Gtk.AttachOptions)(4));
            w56.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame7 = new Gtk.Frame();
            this.frame7.Name = "frame7";
            // Container child frame7.Gtk.Container+ContainerChild
            this.image13 = new Gtk.Image();
            this.image13.Name = "image13";
            this.image13.Pixbuf = Gdk.Pixbuf.LoadFromResource("h2.png");
            this.frame7.Add(this.image13);
            this.pnlUpperScore.Add(this.frame7);
            Gtk.Table.TableChild w58 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame7]));
            w58.LeftAttach = ((uint)(1));
            w58.RightAttach = ((uint)(2));
            w58.XOptions = ((Gtk.AttachOptions)(4));
            w58.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame8 = new Gtk.Frame();
            this.frame8.Name = "frame8";
            // Container child frame8.Gtk.Container+ContainerChild
            this.image3 = new Gtk.Image();
            this.image3.Name = "image3";
            this.image3.Pixbuf = Gdk.Pixbuf.LoadFromResource("dd1.png");
            this.frame8.Add(this.image3);
            this.pnlUpperScore.Add(this.frame8);
            Gtk.Table.TableChild w60 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame8]));
            w60.TopAttach = ((uint)(1));
            w60.BottomAttach = ((uint)(2));
            w60.XOptions = ((Gtk.AttachOptions)(4));
            w60.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.frame9 = new Gtk.Frame();
            this.frame9.Name = "frame9";
            // Container child frame9.Gtk.Container+ContainerChild
            this.image15 = new Gtk.Image();
            this.image15.Name = "image15";
            this.image15.Pixbuf = Gdk.Pixbuf.LoadFromResource("h4.png");
            this.frame9.Add(this.image15);
            this.pnlUpperScore.Add(this.frame9);
            Gtk.Table.TableChild w62 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.frame9]));
            w62.LeftAttach = ((uint)(3));
            w62.RightAttach = ((uint)(4));
            w62.XOptions = ((Gtk.AttachOptions)(4));
            w62.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r0c1 = new Gtk.Frame();
            this.r0c1.Name = "r0c1";
            // Container child r0c1.Gtk.Container+ContainerChild
            this.btnr0c1 = new Gtk.Button();
            this.btnr0c1.WidthRequest = 30;
            this.btnr0c1.HeightRequest = 27;
            this.btnr0c1.CanFocus = true;
            this.btnr0c1.Name = "btnr0c1";
            this.btnr0c1.UseUnderline = true;
            this.btnr0c1.FocusOnClick = false;
            this.btnr0c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr0c1.Label = "";
            this.r0c1.Add(this.btnr0c1);
            this.pnlUpperScore.Add(this.r0c1);
            Gtk.Table.TableChild w64 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r0c1]));
            w64.TopAttach = ((uint)(1));
            w64.BottomAttach = ((uint)(2));
            w64.LeftAttach = ((uint)(2));
            w64.RightAttach = ((uint)(3));
            w64.XOptions = ((Gtk.AttachOptions)(4));
            w64.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r0c2 = new Gtk.Frame();
            this.r0c2.Name = "r0c2";
            // Container child r0c2.Gtk.Container+ContainerChild
            this.btnr0c2 = new Gtk.Button();
            this.btnr0c2.WidthRequest = 30;
            this.btnr0c2.HeightRequest = 27;
            this.btnr0c2.CanFocus = true;
            this.btnr0c2.Name = "btnr0c2";
            this.btnr0c2.UseUnderline = true;
            this.btnr0c2.FocusOnClick = false;
            this.btnr0c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr0c2.Label = "";
            this.r0c2.Add(this.btnr0c2);
            this.pnlUpperScore.Add(this.r0c2);
            Gtk.Table.TableChild w66 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r0c2]));
            w66.TopAttach = ((uint)(1));
            w66.BottomAttach = ((uint)(2));
            w66.LeftAttach = ((uint)(3));
            w66.RightAttach = ((uint)(4));
            w66.XOptions = ((Gtk.AttachOptions)(4));
            w66.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r0c3 = new Gtk.Frame();
            this.r0c3.Name = "r0c3";
            // Container child r0c3.Gtk.Container+ContainerChild
            this.btnr0c3 = new Gtk.Button();
            this.btnr0c3.WidthRequest = 30;
            this.btnr0c3.HeightRequest = 27;
            this.btnr0c3.CanFocus = true;
            this.btnr0c3.Name = "btnr0c3";
            this.btnr0c3.UseUnderline = true;
            this.btnr0c3.FocusOnClick = false;
            this.btnr0c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr0c3.Label = "";
            this.r0c3.Add(this.btnr0c3);
            this.pnlUpperScore.Add(this.r0c3);
            Gtk.Table.TableChild w68 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r0c3]));
            w68.TopAttach = ((uint)(1));
            w68.BottomAttach = ((uint)(2));
            w68.LeftAttach = ((uint)(4));
            w68.RightAttach = ((uint)(5));
            w68.XOptions = ((Gtk.AttachOptions)(4));
            w68.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r0c4 = new Gtk.Frame();
            this.r0c4.Name = "r0c4";
            // Container child r0c4.Gtk.Container+ContainerChild
            this.btnr0c4 = new Gtk.Button();
            this.btnr0c4.WidthRequest = 30;
            this.btnr0c4.HeightRequest = 27;
            this.btnr0c4.CanFocus = true;
            this.btnr0c4.Name = "btnr0c4";
            this.btnr0c4.UseUnderline = true;
            this.btnr0c4.FocusOnClick = false;
            this.btnr0c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr0c4.Label = "";
            this.r0c4.Add(this.btnr0c4);
            this.pnlUpperScore.Add(this.r0c4);
            Gtk.Table.TableChild w70 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r0c4]));
            w70.TopAttach = ((uint)(1));
            w70.BottomAttach = ((uint)(2));
            w70.LeftAttach = ((uint)(5));
            w70.RightAttach = ((uint)(6));
            w70.XOptions = ((Gtk.AttachOptions)(4));
            w70.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r0c5 = new Gtk.Frame();
            this.r0c5.Name = "r0c5";
            // Container child r0c5.Gtk.Container+ContainerChild
            this.btnr0c5 = new Gtk.Button();
            this.btnr0c5.WidthRequest = 30;
            this.btnr0c5.HeightRequest = 27;
            this.btnr0c5.CanFocus = true;
            this.btnr0c5.Name = "btnr0c5";
            this.btnr0c5.UseUnderline = true;
            this.btnr0c5.FocusOnClick = false;
            this.btnr0c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr0c5.Label = "";
            this.r0c5.Add(this.btnr0c5);
            this.pnlUpperScore.Add(this.r0c5);
            Gtk.Table.TableChild w72 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r0c5]));
            w72.TopAttach = ((uint)(1));
            w72.BottomAttach = ((uint)(2));
            w72.LeftAttach = ((uint)(6));
            w72.RightAttach = ((uint)(7));
            w72.XOptions = ((Gtk.AttachOptions)(4));
            w72.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r1c1 = new Gtk.Frame();
            this.r1c1.Name = "r1c1";
            // Container child r1c1.Gtk.Container+ContainerChild
            this.btnr1c1 = new Gtk.Button();
            this.btnr1c1.WidthRequest = 30;
            this.btnr1c1.HeightRequest = 27;
            this.btnr1c1.CanFocus = true;
            this.btnr1c1.Name = "btnr1c1";
            this.btnr1c1.UseUnderline = true;
            this.btnr1c1.FocusOnClick = false;
            this.btnr1c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr1c1.Label = "";
            this.r1c1.Add(this.btnr1c1);
            this.pnlUpperScore.Add(this.r1c1);
            Gtk.Table.TableChild w74 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r1c1]));
            w74.TopAttach = ((uint)(2));
            w74.BottomAttach = ((uint)(3));
            w74.LeftAttach = ((uint)(2));
            w74.RightAttach = ((uint)(3));
            w74.XOptions = ((Gtk.AttachOptions)(4));
            w74.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r1c2 = new Gtk.Frame();
            this.r1c2.Name = "r1c2";
            // Container child r1c2.Gtk.Container+ContainerChild
            this.btnr1c2 = new Gtk.Button();
            this.btnr1c2.WidthRequest = 30;
            this.btnr1c2.HeightRequest = 27;
            this.btnr1c2.CanFocus = true;
            this.btnr1c2.Name = "btnr1c2";
            this.btnr1c2.UseUnderline = true;
            this.btnr1c2.FocusOnClick = false;
            this.btnr1c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr1c2.Label = "";
            this.r1c2.Add(this.btnr1c2);
            this.pnlUpperScore.Add(this.r1c2);
            Gtk.Table.TableChild w76 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r1c2]));
            w76.TopAttach = ((uint)(2));
            w76.BottomAttach = ((uint)(3));
            w76.LeftAttach = ((uint)(3));
            w76.RightAttach = ((uint)(4));
            w76.XOptions = ((Gtk.AttachOptions)(4));
            w76.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r1c3 = new Gtk.Frame();
            this.r1c3.Name = "r1c3";
            // Container child r1c3.Gtk.Container+ContainerChild
            this.btnr1c3 = new Gtk.Button();
            this.btnr1c3.WidthRequest = 30;
            this.btnr1c3.HeightRequest = 27;
            this.btnr1c3.CanFocus = true;
            this.btnr1c3.Name = "btnr1c3";
            this.btnr1c3.UseUnderline = true;
            this.btnr1c3.FocusOnClick = false;
            this.btnr1c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr1c3.Label = "";
            this.r1c3.Add(this.btnr1c3);
            this.pnlUpperScore.Add(this.r1c3);
            Gtk.Table.TableChild w78 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r1c3]));
            w78.TopAttach = ((uint)(2));
            w78.BottomAttach = ((uint)(3));
            w78.LeftAttach = ((uint)(4));
            w78.RightAttach = ((uint)(5));
            w78.XOptions = ((Gtk.AttachOptions)(4));
            w78.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r1c4 = new Gtk.Frame();
            this.r1c4.Name = "r1c4";
            // Container child r1c4.Gtk.Container+ContainerChild
            this.btnr1c4 = new Gtk.Button();
            this.btnr1c4.WidthRequest = 30;
            this.btnr1c4.HeightRequest = 27;
            this.btnr1c4.CanFocus = true;
            this.btnr1c4.Name = "btnr1c4";
            this.btnr1c4.UseUnderline = true;
            this.btnr1c4.FocusOnClick = false;
            this.btnr1c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr1c4.Label = "";
            this.r1c4.Add(this.btnr1c4);
            this.pnlUpperScore.Add(this.r1c4);
            Gtk.Table.TableChild w80 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r1c4]));
            w80.TopAttach = ((uint)(2));
            w80.BottomAttach = ((uint)(3));
            w80.LeftAttach = ((uint)(5));
            w80.RightAttach = ((uint)(6));
            w80.XOptions = ((Gtk.AttachOptions)(4));
            w80.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r1c5 = new Gtk.Frame();
            this.r1c5.Name = "r1c5";
            // Container child r1c5.Gtk.Container+ContainerChild
            this.btnr1c5 = new Gtk.Button();
            this.btnr1c5.WidthRequest = 30;
            this.btnr1c5.HeightRequest = 27;
            this.btnr1c5.CanFocus = true;
            this.btnr1c5.Name = "btnr1c5";
            this.btnr1c5.UseUnderline = true;
            this.btnr1c5.FocusOnClick = false;
            this.btnr1c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr1c5.Label = "";
            this.r1c5.Add(this.btnr1c5);
            this.pnlUpperScore.Add(this.r1c5);
            Gtk.Table.TableChild w82 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r1c5]));
            w82.TopAttach = ((uint)(2));
            w82.BottomAttach = ((uint)(3));
            w82.LeftAttach = ((uint)(6));
            w82.RightAttach = ((uint)(7));
            w82.XOptions = ((Gtk.AttachOptions)(4));
            w82.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r2c1 = new Gtk.Frame();
            this.r2c1.Name = "r2c1";
            // Container child r2c1.Gtk.Container+ContainerChild
            this.btnr2c1 = new Gtk.Button();
            this.btnr2c1.WidthRequest = 30;
            this.btnr2c1.HeightRequest = 27;
            this.btnr2c1.CanFocus = true;
            this.btnr2c1.Name = "btnr2c1";
            this.btnr2c1.UseUnderline = true;
            this.btnr2c1.FocusOnClick = false;
            this.btnr2c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr2c1.Label = "";
            this.r2c1.Add(this.btnr2c1);
            this.pnlUpperScore.Add(this.r2c1);
            Gtk.Table.TableChild w84 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r2c1]));
            w84.TopAttach = ((uint)(3));
            w84.BottomAttach = ((uint)(4));
            w84.LeftAttach = ((uint)(2));
            w84.RightAttach = ((uint)(3));
            w84.XOptions = ((Gtk.AttachOptions)(4));
            w84.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r2c2 = new Gtk.Frame();
            this.r2c2.Name = "r2c2";
            // Container child r2c2.Gtk.Container+ContainerChild
            this.btnr2c2 = new Gtk.Button();
            this.btnr2c2.WidthRequest = 30;
            this.btnr2c2.HeightRequest = 27;
            this.btnr2c2.CanFocus = true;
            this.btnr2c2.Name = "btnr2c2";
            this.btnr2c2.UseUnderline = true;
            this.btnr2c2.FocusOnClick = false;
            this.btnr2c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr2c2.Label = "";
            this.r2c2.Add(this.btnr2c2);
            this.pnlUpperScore.Add(this.r2c2);
            Gtk.Table.TableChild w86 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r2c2]));
            w86.TopAttach = ((uint)(3));
            w86.BottomAttach = ((uint)(4));
            w86.LeftAttach = ((uint)(3));
            w86.RightAttach = ((uint)(4));
            w86.XOptions = ((Gtk.AttachOptions)(4));
            w86.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r2c3 = new Gtk.Frame();
            this.r2c3.Name = "r2c3";
            // Container child r2c3.Gtk.Container+ContainerChild
            this.btnr2c3 = new Gtk.Button();
            this.btnr2c3.WidthRequest = 30;
            this.btnr2c3.HeightRequest = 27;
            this.btnr2c3.CanFocus = true;
            this.btnr2c3.Name = "btnr2c3";
            this.btnr2c3.UseUnderline = true;
            this.btnr2c3.FocusOnClick = false;
            this.btnr2c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr2c3.Label = "";
            this.r2c3.Add(this.btnr2c3);
            this.pnlUpperScore.Add(this.r2c3);
            Gtk.Table.TableChild w88 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r2c3]));
            w88.TopAttach = ((uint)(3));
            w88.BottomAttach = ((uint)(4));
            w88.LeftAttach = ((uint)(4));
            w88.RightAttach = ((uint)(5));
            w88.XOptions = ((Gtk.AttachOptions)(4));
            w88.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r2c4 = new Gtk.Frame();
            this.r2c4.Name = "r2c4";
            // Container child r2c4.Gtk.Container+ContainerChild
            this.btnr2c4 = new Gtk.Button();
            this.btnr2c4.WidthRequest = 30;
            this.btnr2c4.HeightRequest = 27;
            this.btnr2c4.CanFocus = true;
            this.btnr2c4.Name = "btnr2c4";
            this.btnr2c4.UseUnderline = true;
            this.btnr2c4.FocusOnClick = false;
            this.btnr2c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr2c4.Label = "";
            this.r2c4.Add(this.btnr2c4);
            this.pnlUpperScore.Add(this.r2c4);
            Gtk.Table.TableChild w90 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r2c4]));
            w90.TopAttach = ((uint)(3));
            w90.BottomAttach = ((uint)(4));
            w90.LeftAttach = ((uint)(5));
            w90.RightAttach = ((uint)(6));
            w90.XOptions = ((Gtk.AttachOptions)(4));
            w90.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r2c5 = new Gtk.Frame();
            this.r2c5.Name = "r2c5";
            // Container child r2c5.Gtk.Container+ContainerChild
            this.btnr2c5 = new Gtk.Button();
            this.btnr2c5.WidthRequest = 30;
            this.btnr2c5.HeightRequest = 27;
            this.btnr2c5.CanFocus = true;
            this.btnr2c5.Name = "btnr2c5";
            this.btnr2c5.UseUnderline = true;
            this.btnr2c5.FocusOnClick = false;
            this.btnr2c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr2c5.Label = "";
            this.r2c5.Add(this.btnr2c5);
            this.pnlUpperScore.Add(this.r2c5);
            Gtk.Table.TableChild w92 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r2c5]));
            w92.TopAttach = ((uint)(3));
            w92.BottomAttach = ((uint)(4));
            w92.LeftAttach = ((uint)(6));
            w92.RightAttach = ((uint)(7));
            w92.XOptions = ((Gtk.AttachOptions)(4));
            w92.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r3c1 = new Gtk.Frame();
            this.r3c1.Name = "r3c1";
            // Container child r3c1.Gtk.Container+ContainerChild
            this.btnr3c1 = new Gtk.Button();
            this.btnr3c1.WidthRequest = 30;
            this.btnr3c1.HeightRequest = 27;
            this.btnr3c1.CanFocus = true;
            this.btnr3c1.Name = "btnr3c1";
            this.btnr3c1.UseUnderline = true;
            this.btnr3c1.FocusOnClick = false;
            this.btnr3c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr3c1.Label = "";
            this.r3c1.Add(this.btnr3c1);
            this.pnlUpperScore.Add(this.r3c1);
            Gtk.Table.TableChild w94 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r3c1]));
            w94.TopAttach = ((uint)(4));
            w94.BottomAttach = ((uint)(5));
            w94.LeftAttach = ((uint)(2));
            w94.RightAttach = ((uint)(3));
            w94.XOptions = ((Gtk.AttachOptions)(4));
            w94.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r3c2 = new Gtk.Frame();
            this.r3c2.Name = "r3c2";
            // Container child r3c2.Gtk.Container+ContainerChild
            this.btnr3c2 = new Gtk.Button();
            this.btnr3c2.WidthRequest = 30;
            this.btnr3c2.HeightRequest = 27;
            this.btnr3c2.CanFocus = true;
            this.btnr3c2.Name = "btnr3c2";
            this.btnr3c2.UseUnderline = true;
            this.btnr3c2.FocusOnClick = false;
            this.btnr3c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr3c2.Label = "";
            this.r3c2.Add(this.btnr3c2);
            this.pnlUpperScore.Add(this.r3c2);
            Gtk.Table.TableChild w96 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r3c2]));
            w96.TopAttach = ((uint)(4));
            w96.BottomAttach = ((uint)(5));
            w96.LeftAttach = ((uint)(3));
            w96.RightAttach = ((uint)(4));
            w96.XOptions = ((Gtk.AttachOptions)(4));
            w96.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r3c3 = new Gtk.Frame();
            this.r3c3.Name = "r3c3";
            // Container child r3c3.Gtk.Container+ContainerChild
            this.btnr3c3 = new Gtk.Button();
            this.btnr3c3.WidthRequest = 30;
            this.btnr3c3.HeightRequest = 27;
            this.btnr3c3.CanFocus = true;
            this.btnr3c3.Name = "btnr3c3";
            this.btnr3c3.UseUnderline = true;
            this.btnr3c3.FocusOnClick = false;
            this.btnr3c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr3c3.Label = "";
            this.r3c3.Add(this.btnr3c3);
            this.pnlUpperScore.Add(this.r3c3);
            Gtk.Table.TableChild w98 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r3c3]));
            w98.TopAttach = ((uint)(4));
            w98.BottomAttach = ((uint)(5));
            w98.LeftAttach = ((uint)(4));
            w98.RightAttach = ((uint)(5));
            w98.XOptions = ((Gtk.AttachOptions)(4));
            w98.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r3c4 = new Gtk.Frame();
            this.r3c4.Name = "r3c4";
            // Container child r3c4.Gtk.Container+ContainerChild
            this.btnr3c4 = new Gtk.Button();
            this.btnr3c4.WidthRequest = 30;
            this.btnr3c4.HeightRequest = 27;
            this.btnr3c4.CanFocus = true;
            this.btnr3c4.Name = "btnr3c4";
            this.btnr3c4.UseUnderline = true;
            this.btnr3c4.FocusOnClick = false;
            this.btnr3c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr3c4.Label = "";
            this.r3c4.Add(this.btnr3c4);
            this.pnlUpperScore.Add(this.r3c4);
            Gtk.Table.TableChild w100 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r3c4]));
            w100.TopAttach = ((uint)(4));
            w100.BottomAttach = ((uint)(5));
            w100.LeftAttach = ((uint)(5));
            w100.RightAttach = ((uint)(6));
            w100.XOptions = ((Gtk.AttachOptions)(4));
            w100.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r3c5 = new Gtk.Frame();
            this.r3c5.Name = "r3c5";
            // Container child r3c5.Gtk.Container+ContainerChild
            this.btnr3c5 = new Gtk.Button();
            this.btnr3c5.WidthRequest = 30;
            this.btnr3c5.HeightRequest = 27;
            this.btnr3c5.CanFocus = true;
            this.btnr3c5.Name = "btnr3c5";
            this.btnr3c5.UseUnderline = true;
            this.btnr3c5.FocusOnClick = false;
            this.btnr3c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr3c5.Label = "";
            this.r3c5.Add(this.btnr3c5);
            this.pnlUpperScore.Add(this.r3c5);
            Gtk.Table.TableChild w102 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r3c5]));
            w102.TopAttach = ((uint)(4));
            w102.BottomAttach = ((uint)(5));
            w102.LeftAttach = ((uint)(6));
            w102.RightAttach = ((uint)(7));
            w102.XOptions = ((Gtk.AttachOptions)(4));
            w102.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r4c1 = new Gtk.Frame();
            this.r4c1.Name = "r4c1";
            // Container child r4c1.Gtk.Container+ContainerChild
            this.btnr4c1 = new Gtk.Button();
            this.btnr4c1.WidthRequest = 30;
            this.btnr4c1.HeightRequest = 27;
            this.btnr4c1.CanFocus = true;
            this.btnr4c1.Name = "btnr4c1";
            this.btnr4c1.UseUnderline = true;
            this.btnr4c1.FocusOnClick = false;
            this.btnr4c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr4c1.Label = "";
            this.r4c1.Add(this.btnr4c1);
            this.pnlUpperScore.Add(this.r4c1);
            Gtk.Table.TableChild w104 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r4c1]));
            w104.TopAttach = ((uint)(5));
            w104.BottomAttach = ((uint)(6));
            w104.LeftAttach = ((uint)(2));
            w104.RightAttach = ((uint)(3));
            w104.XOptions = ((Gtk.AttachOptions)(4));
            w104.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r4c2 = new Gtk.Frame();
            this.r4c2.Name = "r4c2";
            // Container child r4c2.Gtk.Container+ContainerChild
            this.btnr4c2 = new Gtk.Button();
            this.btnr4c2.WidthRequest = 30;
            this.btnr4c2.HeightRequest = 27;
            this.btnr4c2.CanFocus = true;
            this.btnr4c2.Name = "btnr4c2";
            this.btnr4c2.UseUnderline = true;
            this.btnr4c2.FocusOnClick = false;
            this.btnr4c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr4c2.Label = "";
            this.r4c2.Add(this.btnr4c2);
            this.pnlUpperScore.Add(this.r4c2);
            Gtk.Table.TableChild w106 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r4c2]));
            w106.TopAttach = ((uint)(5));
            w106.BottomAttach = ((uint)(6));
            w106.LeftAttach = ((uint)(3));
            w106.RightAttach = ((uint)(4));
            w106.XOptions = ((Gtk.AttachOptions)(4));
            w106.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r4c3 = new Gtk.Frame();
            this.r4c3.Name = "r4c3";
            // Container child r4c3.Gtk.Container+ContainerChild
            this.btnr4c3 = new Gtk.Button();
            this.btnr4c3.WidthRequest = 30;
            this.btnr4c3.HeightRequest = 27;
            this.btnr4c3.CanFocus = true;
            this.btnr4c3.Name = "btnr4c3";
            this.btnr4c3.UseUnderline = true;
            this.btnr4c3.FocusOnClick = false;
            this.btnr4c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr4c3.Label = "";
            this.r4c3.Add(this.btnr4c3);
            this.pnlUpperScore.Add(this.r4c3);
            Gtk.Table.TableChild w108 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r4c3]));
            w108.TopAttach = ((uint)(5));
            w108.BottomAttach = ((uint)(6));
            w108.LeftAttach = ((uint)(4));
            w108.RightAttach = ((uint)(5));
            w108.XOptions = ((Gtk.AttachOptions)(4));
            w108.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r4c4 = new Gtk.Frame();
            this.r4c4.Name = "r4c4";
            // Container child r4c4.Gtk.Container+ContainerChild
            this.btnr4c4 = new Gtk.Button();
            this.btnr4c4.WidthRequest = 30;
            this.btnr4c4.HeightRequest = 27;
            this.btnr4c4.CanFocus = true;
            this.btnr4c4.Name = "btnr4c4";
            this.btnr4c4.UseUnderline = true;
            this.btnr4c4.FocusOnClick = false;
            this.btnr4c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr4c4.Label = "";
            this.r4c4.Add(this.btnr4c4);
            this.pnlUpperScore.Add(this.r4c4);
            Gtk.Table.TableChild w110 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r4c4]));
            w110.TopAttach = ((uint)(5));
            w110.BottomAttach = ((uint)(6));
            w110.LeftAttach = ((uint)(5));
            w110.RightAttach = ((uint)(6));
            w110.XOptions = ((Gtk.AttachOptions)(4));
            w110.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r4c5 = new Gtk.Frame();
            this.r4c5.Name = "r4c5";
            // Container child r4c5.Gtk.Container+ContainerChild
            this.btnr4c5 = new Gtk.Button();
            this.btnr4c5.WidthRequest = 30;
            this.btnr4c5.HeightRequest = 27;
            this.btnr4c5.CanFocus = true;
            this.btnr4c5.Name = "btnr4c5";
            this.btnr4c5.UseUnderline = true;
            this.btnr4c5.FocusOnClick = false;
            this.btnr4c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr4c5.Label = "";
            this.r4c5.Add(this.btnr4c5);
            this.pnlUpperScore.Add(this.r4c5);
            Gtk.Table.TableChild w112 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r4c5]));
            w112.TopAttach = ((uint)(5));
            w112.BottomAttach = ((uint)(6));
            w112.LeftAttach = ((uint)(6));
            w112.RightAttach = ((uint)(7));
            w112.XOptions = ((Gtk.AttachOptions)(4));
            w112.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r5c1 = new Gtk.Frame();
            this.r5c1.Name = "r5c1";
            // Container child r5c1.Gtk.Container+ContainerChild
            this.btnr5c1 = new Gtk.Button();
            this.btnr5c1.WidthRequest = 30;
            this.btnr5c1.HeightRequest = 27;
            this.btnr5c1.CanFocus = true;
            this.btnr5c1.Name = "btnr5c1";
            this.btnr5c1.UseUnderline = true;
            this.btnr5c1.FocusOnClick = false;
            this.btnr5c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr5c1.Label = "";
            this.r5c1.Add(this.btnr5c1);
            this.pnlUpperScore.Add(this.r5c1);
            Gtk.Table.TableChild w114 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r5c1]));
            w114.TopAttach = ((uint)(6));
            w114.BottomAttach = ((uint)(7));
            w114.LeftAttach = ((uint)(2));
            w114.RightAttach = ((uint)(3));
            w114.XOptions = ((Gtk.AttachOptions)(4));
            w114.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r5c2 = new Gtk.Frame();
            this.r5c2.Name = "r5c2";
            // Container child r5c2.Gtk.Container+ContainerChild
            this.btnr5c2 = new Gtk.Button();
            this.btnr5c2.WidthRequest = 30;
            this.btnr5c2.HeightRequest = 27;
            this.btnr5c2.CanFocus = true;
            this.btnr5c2.Name = "btnr5c2";
            this.btnr5c2.UseUnderline = true;
            this.btnr5c2.FocusOnClick = false;
            this.btnr5c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr5c2.Label = "";
            this.r5c2.Add(this.btnr5c2);
            this.pnlUpperScore.Add(this.r5c2);
            Gtk.Table.TableChild w116 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r5c2]));
            w116.TopAttach = ((uint)(6));
            w116.BottomAttach = ((uint)(7));
            w116.LeftAttach = ((uint)(3));
            w116.RightAttach = ((uint)(4));
            w116.XOptions = ((Gtk.AttachOptions)(4));
            w116.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r5c3 = new Gtk.Frame();
            this.r5c3.Name = "r5c3";
            // Container child r5c3.Gtk.Container+ContainerChild
            this.btnr5c3 = new Gtk.Button();
            this.btnr5c3.WidthRequest = 30;
            this.btnr5c3.HeightRequest = 27;
            this.btnr5c3.CanFocus = true;
            this.btnr5c3.Name = "btnr5c3";
            this.btnr5c3.UseUnderline = true;
            this.btnr5c3.FocusOnClick = false;
            this.btnr5c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr5c3.Label = "";
            this.r5c3.Add(this.btnr5c3);
            this.pnlUpperScore.Add(this.r5c3);
            Gtk.Table.TableChild w118 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r5c3]));
            w118.TopAttach = ((uint)(6));
            w118.BottomAttach = ((uint)(7));
            w118.LeftAttach = ((uint)(4));
            w118.RightAttach = ((uint)(5));
            w118.XOptions = ((Gtk.AttachOptions)(4));
            w118.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r5c4 = new Gtk.Frame();
            this.r5c4.Name = "r5c4";
            // Container child r5c4.Gtk.Container+ContainerChild
            this.btnr5c4 = new Gtk.Button();
            this.btnr5c4.WidthRequest = 30;
            this.btnr5c4.HeightRequest = 27;
            this.btnr5c4.CanFocus = true;
            this.btnr5c4.Name = "btnr5c4";
            this.btnr5c4.UseUnderline = true;
            this.btnr5c4.FocusOnClick = false;
            this.btnr5c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr5c4.Label = "";
            this.r5c4.Add(this.btnr5c4);
            this.pnlUpperScore.Add(this.r5c4);
            Gtk.Table.TableChild w120 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r5c4]));
            w120.TopAttach = ((uint)(6));
            w120.BottomAttach = ((uint)(7));
            w120.LeftAttach = ((uint)(5));
            w120.RightAttach = ((uint)(6));
            w120.XOptions = ((Gtk.AttachOptions)(4));
            w120.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r5c5 = new Gtk.Frame();
            this.r5c5.Name = "r5c5";
            // Container child r5c5.Gtk.Container+ContainerChild
            this.btnr5c5 = new Gtk.Button();
            this.btnr5c5.WidthRequest = 30;
            this.btnr5c5.HeightRequest = 27;
            this.btnr5c5.CanFocus = true;
            this.btnr5c5.Name = "btnr5c5";
            this.btnr5c5.UseUnderline = true;
            this.btnr5c5.FocusOnClick = false;
            this.btnr5c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr5c5.Label = "";
            this.r5c5.Add(this.btnr5c5);
            this.pnlUpperScore.Add(this.r5c5);
            Gtk.Table.TableChild w122 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r5c5]));
            w122.TopAttach = ((uint)(6));
            w122.BottomAttach = ((uint)(7));
            w122.LeftAttach = ((uint)(6));
            w122.RightAttach = ((uint)(7));
            w122.XOptions = ((Gtk.AttachOptions)(4));
            w122.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r6c1 = new Gtk.Frame();
            this.r6c1.Name = "r6c1";
            // Container child r6c1.Gtk.Container+ContainerChild
            this.btnr6c1 = new Gtk.Label();
            this.btnr6c1.Name = "btnr6c1";
            this.btnr6c1.Justify = ((Gtk.Justification)(2));
            this.r6c1.Add(this.btnr6c1);
            this.pnlUpperScore.Add(this.r6c1);
            Gtk.Table.TableChild w124 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r6c1]));
            w124.TopAttach = ((uint)(7));
            w124.BottomAttach = ((uint)(8));
            w124.LeftAttach = ((uint)(2));
            w124.RightAttach = ((uint)(3));
            w124.XOptions = ((Gtk.AttachOptions)(4));
            w124.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r6c2 = new Gtk.Frame();
            this.r6c2.Name = "r6c2";
            // Container child r6c2.Gtk.Container+ContainerChild
            this.btnr6c2 = new Gtk.Label();
            this.btnr6c2.Name = "btnr6c2";
            this.btnr6c2.Justify = ((Gtk.Justification)(2));
            this.r6c2.Add(this.btnr6c2);
            this.pnlUpperScore.Add(this.r6c2);
            Gtk.Table.TableChild w126 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r6c2]));
            w126.TopAttach = ((uint)(7));
            w126.BottomAttach = ((uint)(8));
            w126.LeftAttach = ((uint)(3));
            w126.RightAttach = ((uint)(4));
            w126.XOptions = ((Gtk.AttachOptions)(4));
            w126.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r6c3 = new Gtk.Frame();
            this.r6c3.Name = "r6c3";
            // Container child r6c3.Gtk.Container+ContainerChild
            this.btnr6c3 = new Gtk.Label();
            this.btnr6c3.Name = "btnr6c3";
            this.btnr6c3.Justify = ((Gtk.Justification)(2));
            this.r6c3.Add(this.btnr6c3);
            this.pnlUpperScore.Add(this.r6c3);
            Gtk.Table.TableChild w128 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r6c3]));
            w128.TopAttach = ((uint)(7));
            w128.BottomAttach = ((uint)(8));
            w128.LeftAttach = ((uint)(4));
            w128.RightAttach = ((uint)(5));
            w128.XOptions = ((Gtk.AttachOptions)(4));
            w128.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r6c4 = new Gtk.Frame();
            this.r6c4.Name = "r6c4";
            // Container child r6c4.Gtk.Container+ContainerChild
            this.btnr6c4 = new Gtk.Label();
            this.btnr6c4.Name = "btnr6c4";
            this.btnr6c4.Justify = ((Gtk.Justification)(2));
            this.r6c4.Add(this.btnr6c4);
            this.pnlUpperScore.Add(this.r6c4);
            Gtk.Table.TableChild w130 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r6c4]));
            w130.TopAttach = ((uint)(7));
            w130.BottomAttach = ((uint)(8));
            w130.LeftAttach = ((uint)(5));
            w130.RightAttach = ((uint)(6));
            w130.XOptions = ((Gtk.AttachOptions)(4));
            w130.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r6c5 = new Gtk.Frame();
            this.r6c5.Name = "r6c5";
            // Container child r6c5.Gtk.Container+ContainerChild
            this.btnr6c5 = new Gtk.Label();
            this.btnr6c5.Name = "btnr6c5";
            this.btnr6c5.Justify = ((Gtk.Justification)(2));
            this.r6c5.Add(this.btnr6c5);
            this.pnlUpperScore.Add(this.r6c5);
            Gtk.Table.TableChild w132 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r6c5]));
            w132.TopAttach = ((uint)(7));
            w132.BottomAttach = ((uint)(8));
            w132.LeftAttach = ((uint)(6));
            w132.RightAttach = ((uint)(7));
            w132.XOptions = ((Gtk.AttachOptions)(4));
            w132.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r7c1 = new Gtk.Frame();
            this.r7c1.Name = "r7c1";
            // Container child r7c1.Gtk.Container+ContainerChild
            this.btnr7c1 = new Gtk.Label();
            this.btnr7c1.Name = "btnr7c1";
            this.btnr7c1.Justify = ((Gtk.Justification)(2));
            this.r7c1.Add(this.btnr7c1);
            this.pnlUpperScore.Add(this.r7c1);
            Gtk.Table.TableChild w134 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r7c1]));
            w134.TopAttach = ((uint)(8));
            w134.BottomAttach = ((uint)(9));
            w134.LeftAttach = ((uint)(2));
            w134.RightAttach = ((uint)(3));
            w134.XOptions = ((Gtk.AttachOptions)(4));
            w134.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r7c2 = new Gtk.Frame();
            this.r7c2.Name = "r7c2";
            // Container child r7c2.Gtk.Container+ContainerChild
            this.btnr7c2 = new Gtk.Label();
            this.btnr7c2.Name = "btnr7c2";
            this.btnr7c2.Justify = ((Gtk.Justification)(2));
            this.r7c2.Add(this.btnr7c2);
            this.pnlUpperScore.Add(this.r7c2);
            Gtk.Table.TableChild w136 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r7c2]));
            w136.TopAttach = ((uint)(8));
            w136.BottomAttach = ((uint)(9));
            w136.LeftAttach = ((uint)(3));
            w136.RightAttach = ((uint)(4));
            w136.XOptions = ((Gtk.AttachOptions)(4));
            w136.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r7c3 = new Gtk.Frame();
            this.r7c3.Name = "r7c3";
            // Container child r7c3.Gtk.Container+ContainerChild
            this.btnr7c3 = new Gtk.Label();
            this.btnr7c3.Name = "btnr7c3";
            this.btnr7c3.Justify = ((Gtk.Justification)(2));
            this.r7c3.Add(this.btnr7c3);
            this.pnlUpperScore.Add(this.r7c3);
            Gtk.Table.TableChild w138 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r7c3]));
            w138.TopAttach = ((uint)(8));
            w138.BottomAttach = ((uint)(9));
            w138.LeftAttach = ((uint)(4));
            w138.RightAttach = ((uint)(5));
            w138.XOptions = ((Gtk.AttachOptions)(4));
            w138.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r7c4 = new Gtk.Frame();
            this.r7c4.Name = "r7c4";
            // Container child r7c4.Gtk.Container+ContainerChild
            this.btnr7c4 = new Gtk.Label();
            this.btnr7c4.Name = "btnr7c4";
            this.btnr7c4.Justify = ((Gtk.Justification)(2));
            this.r7c4.Add(this.btnr7c4);
            this.pnlUpperScore.Add(this.r7c4);
            Gtk.Table.TableChild w140 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r7c4]));
            w140.TopAttach = ((uint)(8));
            w140.BottomAttach = ((uint)(9));
            w140.LeftAttach = ((uint)(5));
            w140.RightAttach = ((uint)(6));
            w140.XOptions = ((Gtk.AttachOptions)(4));
            w140.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r7c5 = new Gtk.Frame();
            this.r7c5.Name = "r7c5";
            // Container child r7c5.Gtk.Container+ContainerChild
            this.btnr7c5 = new Gtk.Label();
            this.btnr7c5.Name = "btnr7c5";
            this.btnr7c5.Justify = ((Gtk.Justification)(2));
            this.r7c5.Add(this.btnr7c5);
            this.pnlUpperScore.Add(this.r7c5);
            Gtk.Table.TableChild w142 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r7c5]));
            w142.TopAttach = ((uint)(8));
            w142.BottomAttach = ((uint)(9));
            w142.LeftAttach = ((uint)(6));
            w142.RightAttach = ((uint)(7));
            w142.XOptions = ((Gtk.AttachOptions)(4));
            w142.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r8c1 = new Gtk.Frame();
            this.r8c1.Name = "r8c1";
            // Container child r8c1.Gtk.Container+ContainerChild
            this.btnr8c1 = new Gtk.Label();
            this.btnr8c1.Name = "btnr8c1";
            this.btnr8c1.Justify = ((Gtk.Justification)(2));
            this.r8c1.Add(this.btnr8c1);
            this.pnlUpperScore.Add(this.r8c1);
            Gtk.Table.TableChild w144 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r8c1]));
            w144.TopAttach = ((uint)(9));
            w144.BottomAttach = ((uint)(10));
            w144.LeftAttach = ((uint)(2));
            w144.RightAttach = ((uint)(3));
            w144.XOptions = ((Gtk.AttachOptions)(4));
            w144.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r8c2 = new Gtk.Frame();
            this.r8c2.Name = "r8c2";
            // Container child r8c2.Gtk.Container+ContainerChild
            this.btnr8c2 = new Gtk.Label();
            this.btnr8c2.Name = "btnr8c2";
            this.btnr8c2.Justify = ((Gtk.Justification)(2));
            this.r8c2.Add(this.btnr8c2);
            this.pnlUpperScore.Add(this.r8c2);
            Gtk.Table.TableChild w146 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r8c2]));
            w146.TopAttach = ((uint)(9));
            w146.BottomAttach = ((uint)(10));
            w146.LeftAttach = ((uint)(3));
            w146.RightAttach = ((uint)(4));
            w146.XOptions = ((Gtk.AttachOptions)(4));
            w146.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r8c3 = new Gtk.Frame();
            this.r8c3.Name = "r8c3";
            // Container child r8c3.Gtk.Container+ContainerChild
            this.btnr8c3 = new Gtk.Label();
            this.btnr8c3.Name = "btnr8c3";
            this.btnr8c3.Justify = ((Gtk.Justification)(2));
            this.r8c3.Add(this.btnr8c3);
            this.pnlUpperScore.Add(this.r8c3);
            Gtk.Table.TableChild w148 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r8c3]));
            w148.TopAttach = ((uint)(9));
            w148.BottomAttach = ((uint)(10));
            w148.LeftAttach = ((uint)(4));
            w148.RightAttach = ((uint)(5));
            w148.XOptions = ((Gtk.AttachOptions)(4));
            w148.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r8c4 = new Gtk.Frame();
            this.r8c4.Name = "r8c4";
            // Container child r8c4.Gtk.Container+ContainerChild
            this.btnr8c4 = new Gtk.Label();
            this.btnr8c4.Name = "btnr8c4";
            this.btnr8c4.Justify = ((Gtk.Justification)(2));
            this.r8c4.Add(this.btnr8c4);
            this.pnlUpperScore.Add(this.r8c4);
            Gtk.Table.TableChild w150 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r8c4]));
            w150.TopAttach = ((uint)(9));
            w150.BottomAttach = ((uint)(10));
            w150.LeftAttach = ((uint)(5));
            w150.RightAttach = ((uint)(6));
            w150.XOptions = ((Gtk.AttachOptions)(4));
            w150.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlUpperScore.Gtk.Table+TableChild
            this.r8c5 = new Gtk.Frame();
            this.r8c5.Name = "r8c5";
            // Container child r8c5.Gtk.Container+ContainerChild
            this.btnr8c5 = new Gtk.Label();
            this.btnr8c5.Name = "btnr8c5";
            this.btnr8c5.Justify = ((Gtk.Justification)(2));
            this.r8c5.Add(this.btnr8c5);
            this.pnlUpperScore.Add(this.r8c5);
            Gtk.Table.TableChild w152 = ((Gtk.Table.TableChild)(this.pnlUpperScore[this.r8c5]));
            w152.TopAttach = ((uint)(9));
            w152.BottomAttach = ((uint)(10));
            w152.LeftAttach = ((uint)(6));
            w152.RightAttach = ((uint)(7));
            w152.XOptions = ((Gtk.AttachOptions)(4));
            w152.YOptions = ((Gtk.AttachOptions)(4));
            this.pnloop.Add(this.pnlUpperScore);
            this.vbox4.Add(this.pnloop);
            Gtk.Box.BoxChild w154 = ((Gtk.Box.BoxChild)(this.vbox4[this.pnloop]));
            w154.Position = 0;
            w154.Expand = false;
            w154.Fill = false;
            // Container child vbox4.Gtk.Box+BoxChild
            this.image27 = new Gtk.Image();
            this.image27.Name = "image27";
            this.image27.Xalign = 0.01F;
            this.image27.Pixbuf = Gdk.Pixbuf.LoadFromResource("h1.png");
            this.vbox4.Add(this.image27);
            Gtk.Box.BoxChild w155 = ((Gtk.Box.BoxChild)(this.vbox4[this.image27]));
            w155.Position = 1;
            w155.Expand = false;
            w155.Fill = false;
            // Container child vbox4.Gtk.Box+BoxChild
            this.pnlopps2 = new Gtk.Frame();
            this.pnlopps2.Name = "pnlopps2";
            // Container child pnlopps2.Gtk.Container+ContainerChild
            this.pnlLowerScore = new Gtk.Table(((uint)(12)), ((uint)(7)), false);
            this.pnlLowerScore.Name = "pnlLowerScore";
            this.pnlLowerScore.RowSpacing = ((uint)(6));
            this.pnlLowerScore.ColumnSpacing = ((uint)(6));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame148 = new Gtk.Frame();
            this.frame148.Name = "frame148";
            // Container child frame148.Gtk.Container+ContainerChild
            this.image52 = new Gtk.Image();
            this.image52.Name = "image52";
            this.image52.Pixbuf = Gdk.Pixbuf.LoadFromResource("3oak.png");
            this.frame148.Add(this.image52);
            this.pnlLowerScore.Add(this.frame148);
            Gtk.Table.TableChild w157 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame148]));
            w157.TopAttach = ((uint)(1));
            w157.BottomAttach = ((uint)(2));
            w157.XOptions = ((Gtk.AttachOptions)(4));
            w157.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame153 = new Gtk.Frame();
            this.frame153.Name = "frame153";
            // Container child frame153.Gtk.Container+ContainerChild
            this.image30 = new Gtk.Image();
            this.image30.Name = "image30";
            this.image30.Pixbuf = Gdk.Pixbuf.LoadFromResource("c11.png");
            this.frame153.Add(this.image30);
            this.pnlLowerScore.Add(this.frame153);
            Gtk.Table.TableChild w159 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame153]));
            w159.TopAttach = ((uint)(1));
            w159.BottomAttach = ((uint)(2));
            w159.LeftAttach = ((uint)(1));
            w159.RightAttach = ((uint)(2));
            w159.XOptions = ((Gtk.AttachOptions)(4));
            w159.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame29 = new Gtk.Frame();
            this.frame29.Name = "frame29";
            // Container child frame29.Gtk.Container+ContainerChild
            this.image45 = new Gtk.Image();
            this.image45.Name = "image45";
            this.image45.Pixbuf = Gdk.Pixbuf.LoadFromResource("ph.png");
            this.frame29.Add(this.image45);
            this.pnlLowerScore.Add(this.frame29);
            Gtk.Table.TableChild w161 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame29]));
            w161.TopAttach = ((uint)(3));
            w161.BottomAttach = ((uint)(4));
            w161.XOptions = ((Gtk.AttachOptions)(4));
            w161.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame30 = new Gtk.Frame();
            this.frame30.Name = "frame30";
            // Container child frame30.Gtk.Container+ContainerChild
            this.image29 = new Gtk.Image();
            this.image29.Name = "image29";
            this.image29.Pixbuf = Gdk.Pixbuf.LoadFromResource("arrow_temp.png");
            this.frame30.Add(this.image29);
            this.pnlLowerScore.Add(this.frame30);
            Gtk.Table.TableChild w163 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame30]));
            w163.TopAttach = ((uint)(11));
            w163.BottomAttach = ((uint)(12));
            w163.LeftAttach = ((uint)(1));
            w163.RightAttach = ((uint)(2));
            w163.XOptions = ((Gtk.AttachOptions)(4));
            w163.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame31 = new Gtk.Frame();
            this.frame31.Name = "frame31";
            // Container child frame31.Gtk.Container+ContainerChild
            this.image53 = new Gtk.Image();
            this.image53.Name = "image53";
            this.image53.Pixbuf = Gdk.Pixbuf.LoadFromResource("arrow_temp.png");
            this.frame31.Add(this.image53);
            this.pnlLowerScore.Add(this.frame31);
            Gtk.Table.TableChild w165 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame31]));
            w165.TopAttach = ((uint)(10));
            w165.BottomAttach = ((uint)(11));
            w165.LeftAttach = ((uint)(1));
            w165.RightAttach = ((uint)(2));
            w165.XOptions = ((Gtk.AttachOptions)(4));
            w165.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame32 = new Gtk.Frame();
            this.frame32.Name = "frame32";
            // Container child frame32.Gtk.Container+ContainerChild
            this.image31 = new Gtk.Image();
            this.image31.Name = "image31";
            this.image31.Pixbuf = Gdk.Pixbuf.LoadFromResource("arrow_temp.png");
            this.frame32.Add(this.image31);
            this.pnlLowerScore.Add(this.frame32);
            Gtk.Table.TableChild w167 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame32]));
            w167.TopAttach = ((uint)(9));
            w167.BottomAttach = ((uint)(10));
            w167.LeftAttach = ((uint)(1));
            w167.RightAttach = ((uint)(2));
            w167.XOptions = ((Gtk.AttachOptions)(4));
            w167.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame33 = new Gtk.Frame();
            this.frame33.Name = "frame33";
            // Container child frame33.Gtk.Container+ContainerChild
            this.image32 = new Gtk.Image();
            this.image32.Name = "image32";
            this.image32.Pixbuf = Gdk.Pixbuf.LoadFromResource("ytzBONUStext.png");
            this.frame33.Add(this.image32);
            this.pnlLowerScore.Add(this.frame33);
            Gtk.Table.TableChild w169 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame33]));
            w169.TopAttach = ((uint)(8));
            w169.BottomAttach = ((uint)(9));
            w169.LeftAttach = ((uint)(1));
            w169.RightAttach = ((uint)(2));
            w169.XOptions = ((Gtk.AttachOptions)(4));
            w169.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame34 = new Gtk.Frame();
            this.frame34.Name = "frame34";
            // Container child frame34.Gtk.Container+ContainerChild
            this.image33 = new Gtk.Image();
            this.image33.Name = "image33";
            this.image33.Pixbuf = Gdk.Pixbuf.LoadFromResource("c11.png");
            this.frame34.Add(this.image33);
            this.pnlLowerScore.Add(this.frame34);
            Gtk.Table.TableChild w171 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame34]));
            w171.TopAttach = ((uint)(7));
            w171.BottomAttach = ((uint)(8));
            w171.LeftAttach = ((uint)(1));
            w171.RightAttach = ((uint)(2));
            w171.XOptions = ((Gtk.AttachOptions)(4));
            w171.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame35 = new Gtk.Frame();
            this.frame35.Name = "frame35";
            // Container child frame35.Gtk.Container+ContainerChild
            this.image34 = new Gtk.Image();
            this.image34.Name = "image34";
            this.image34.Pixbuf = Gdk.Pixbuf.LoadFromResource("c5r2.png");
            this.frame35.Add(this.image34);
            this.pnlLowerScore.Add(this.frame35);
            Gtk.Table.TableChild w173 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame35]));
            w173.TopAttach = ((uint)(6));
            w173.BottomAttach = ((uint)(7));
            w173.LeftAttach = ((uint)(1));
            w173.RightAttach = ((uint)(2));
            w173.XOptions = ((Gtk.AttachOptions)(4));
            w173.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame36 = new Gtk.Frame();
            this.frame36.Name = "frame36";
            // Container child frame36.Gtk.Container+ContainerChild
            this.image35 = new Gtk.Image();
            this.image35.Name = "image35";
            this.image35.Pixbuf = Gdk.Pixbuf.LoadFromResource("c4r2.png");
            this.frame36.Add(this.image35);
            this.pnlLowerScore.Add(this.frame36);
            Gtk.Table.TableChild w175 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame36]));
            w175.TopAttach = ((uint)(5));
            w175.BottomAttach = ((uint)(6));
            w175.LeftAttach = ((uint)(1));
            w175.RightAttach = ((uint)(2));
            w175.XOptions = ((Gtk.AttachOptions)(4));
            w175.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame37 = new Gtk.Frame();
            this.frame37.Name = "frame37";
            // Container child frame37.Gtk.Container+ContainerChild
            this.image36 = new Gtk.Image();
            this.image36.Name = "image36";
            this.image36.Pixbuf = Gdk.Pixbuf.LoadFromResource("c3r2.png");
            this.frame37.Add(this.image36);
            this.pnlLowerScore.Add(this.frame37);
            Gtk.Table.TableChild w177 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame37]));
            w177.TopAttach = ((uint)(4));
            w177.BottomAttach = ((uint)(5));
            w177.LeftAttach = ((uint)(1));
            w177.RightAttach = ((uint)(2));
            w177.XOptions = ((Gtk.AttachOptions)(4));
            w177.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame38 = new Gtk.Frame();
            this.frame38.Name = "frame38";
            // Container child frame38.Gtk.Container+ContainerChild
            this.image37 = new Gtk.Image();
            this.image37.Name = "image37";
            this.image37.Pixbuf = Gdk.Pixbuf.LoadFromResource("c2r2.png");
            this.frame38.Add(this.image37);
            this.pnlLowerScore.Add(this.frame38);
            Gtk.Table.TableChild w179 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame38]));
            w179.TopAttach = ((uint)(3));
            w179.BottomAttach = ((uint)(4));
            w179.LeftAttach = ((uint)(1));
            w179.RightAttach = ((uint)(2));
            w179.XOptions = ((Gtk.AttachOptions)(4));
            w179.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame39 = new Gtk.Frame();
            this.frame39.Name = "frame39";
            // Container child frame39.Gtk.Container+ContainerChild
            this.image14 = new Gtk.Image();
            this.image14.Name = "image14";
            this.image14.Pixbuf = Gdk.Pixbuf.LoadFromResource("GT.png");
            this.frame39.Add(this.image14);
            this.pnlLowerScore.Add(this.frame39);
            Gtk.Table.TableChild w181 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame39]));
            w181.TopAttach = ((uint)(11));
            w181.BottomAttach = ((uint)(12));
            w181.XOptions = ((Gtk.AttachOptions)(4));
            w181.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame40 = new Gtk.Frame();
            this.frame40.Name = "frame40";
            // Container child frame40.Gtk.Container+ContainerChild
            this.image38 = new Gtk.Image();
            this.image38.Name = "image38";
            this.image38.Pixbuf = Gdk.Pixbuf.LoadFromResource("totalLower.png");
            this.frame40.Add(this.image38);
            this.pnlLowerScore.Add(this.frame40);
            Gtk.Table.TableChild w183 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame40]));
            w183.TopAttach = ((uint)(10));
            w183.BottomAttach = ((uint)(11));
            w183.XOptions = ((Gtk.AttachOptions)(4));
            w183.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame41 = new Gtk.Frame();
            this.frame41.Name = "frame41";
            // Container child frame41.Gtk.Container+ContainerChild
            this.image55 = new Gtk.Image();
            this.image55.Name = "image55";
            this.image55.Pixbuf = Gdk.Pixbuf.LoadFromResource("totalUpper.png");
            this.frame41.Add(this.image55);
            this.pnlLowerScore.Add(this.frame41);
            Gtk.Table.TableChild w185 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame41]));
            w185.TopAttach = ((uint)(9));
            w185.BottomAttach = ((uint)(10));
            w185.XOptions = ((Gtk.AttachOptions)(4));
            w185.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame42 = new Gtk.Frame();
            this.frame42.Name = "frame42";
            // Container child frame42.Gtk.Container+ContainerChild
            this.image40 = new Gtk.Image();
            this.image40.Name = "image40";
            this.image40.Pixbuf = Gdk.Pixbuf.LoadFromResource("ytzBONUS.png");
            this.frame42.Add(this.image40);
            this.pnlLowerScore.Add(this.frame42);
            Gtk.Table.TableChild w187 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame42]));
            w187.TopAttach = ((uint)(8));
            w187.BottomAttach = ((uint)(9));
            w187.XOptions = ((Gtk.AttachOptions)(4));
            w187.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame43 = new Gtk.Frame();
            this.frame43.Name = "frame43";
            // Container child frame43.Gtk.Container+ContainerChild
            this.image41 = new Gtk.Image();
            this.image41.Name = "image41";
            this.image41.Pixbuf = Gdk.Pixbuf.LoadFromResource("chance.png");
            this.frame43.Add(this.image41);
            this.pnlLowerScore.Add(this.frame43);
            Gtk.Table.TableChild w189 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame43]));
            w189.TopAttach = ((uint)(7));
            w189.BottomAttach = ((uint)(8));
            w189.XOptions = ((Gtk.AttachOptions)(4));
            w189.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame44 = new Gtk.Frame();
            this.frame44.Name = "frame44";
            // Container child frame44.Gtk.Container+ContainerChild
            this.image42 = new Gtk.Image();
            this.image42.Name = "image42";
            this.image42.Pixbuf = Gdk.Pixbuf.LoadFromResource("ytz.png");
            this.frame44.Add(this.image42);
            this.pnlLowerScore.Add(this.frame44);
            Gtk.Table.TableChild w191 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame44]));
            w191.TopAttach = ((uint)(6));
            w191.BottomAttach = ((uint)(7));
            w191.XOptions = ((Gtk.AttachOptions)(4));
            w191.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame45 = new Gtk.Frame();
            this.frame45.Name = "frame45";
            // Container child frame45.Gtk.Container+ContainerChild
            this.image43 = new Gtk.Image();
            this.image43.Name = "image43";
            this.image43.Pixbuf = Gdk.Pixbuf.LoadFromResource("ls.png");
            this.frame45.Add(this.image43);
            this.pnlLowerScore.Add(this.frame45);
            Gtk.Table.TableChild w193 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame45]));
            w193.TopAttach = ((uint)(5));
            w193.BottomAttach = ((uint)(6));
            w193.XOptions = ((Gtk.AttachOptions)(4));
            w193.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame46 = new Gtk.Frame();
            this.frame46.Name = "frame46";
            // Container child frame46.Gtk.Container+ContainerChild
            this.image44 = new Gtk.Image();
            this.image44.Name = "image44";
            this.image44.Pixbuf = Gdk.Pixbuf.LoadFromResource("ss.png");
            this.frame46.Add(this.image44);
            this.pnlLowerScore.Add(this.frame46);
            Gtk.Table.TableChild w195 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame46]));
            w195.TopAttach = ((uint)(4));
            w195.BottomAttach = ((uint)(5));
            w195.XOptions = ((Gtk.AttachOptions)(4));
            w195.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame52 = new Gtk.Frame();
            this.frame52.Name = "frame52";
            // Container child frame52.Gtk.Container+ContainerChild
            this.image39 = new Gtk.Image();
            this.image39.Name = "image39";
            this.image39.Pixbuf = Gdk.Pixbuf.LoadFromResource("c11.png");
            this.frame52.Add(this.image39);
            this.pnlLowerScore.Add(this.frame52);
            Gtk.Table.TableChild w197 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame52]));
            w197.TopAttach = ((uint)(2));
            w197.BottomAttach = ((uint)(3));
            w197.LeftAttach = ((uint)(1));
            w197.RightAttach = ((uint)(2));
            w197.XOptions = ((Gtk.AttachOptions)(4));
            w197.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.frame53 = new Gtk.Frame();
            this.frame53.Name = "frame53";
            // Container child frame53.Gtk.Container+ContainerChild
            this.image28 = new Gtk.Image();
            this.image28.Name = "image28";
            this.image28.Pixbuf = Gdk.Pixbuf.LoadFromResource("4oak.png");
            this.frame53.Add(this.image28);
            this.pnlLowerScore.Add(this.frame53);
            Gtk.Table.TableChild w199 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.frame53]));
            w199.TopAttach = ((uint)(2));
            w199.BottomAttach = ((uint)(3));
            w199.XOptions = ((Gtk.AttachOptions)(4));
            w199.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.hseparator1 = new Gtk.HSeparator();
            this.hseparator1.WidthRequest = 47;
            this.hseparator1.Name = "hseparator1";
            this.pnlLowerScore.Add(this.hseparator1);
            Gtk.Table.TableChild w200 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.hseparator1]));
            w200.LeftAttach = ((uint)(6));
            w200.RightAttach = ((uint)(7));
            w200.XOptions = ((Gtk.AttachOptions)(4));
            w200.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.hseparator4 = new Gtk.HSeparator();
            this.hseparator4.WidthRequest = 47;
            this.hseparator4.Name = "hseparator4";
            this.pnlLowerScore.Add(this.hseparator4);
            Gtk.Table.TableChild w201 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.hseparator4]));
            w201.LeftAttach = ((uint)(2));
            w201.RightAttach = ((uint)(3));
            w201.XOptions = ((Gtk.AttachOptions)(4));
            w201.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.hseparator5 = new Gtk.HSeparator();
            this.hseparator5.WidthRequest = 47;
            this.hseparator5.Name = "hseparator5";
            this.pnlLowerScore.Add(this.hseparator5);
            Gtk.Table.TableChild w202 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.hseparator5]));
            w202.LeftAttach = ((uint)(3));
            w202.RightAttach = ((uint)(4));
            w202.XOptions = ((Gtk.AttachOptions)(4));
            w202.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.hseparator6 = new Gtk.HSeparator();
            this.hseparator6.WidthRequest = 47;
            this.hseparator6.Name = "hseparator6";
            this.pnlLowerScore.Add(this.hseparator6);
            Gtk.Table.TableChild w203 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.hseparator6]));
            w203.LeftAttach = ((uint)(4));
            w203.RightAttach = ((uint)(5));
            w203.XOptions = ((Gtk.AttachOptions)(4));
            w203.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.hseparator7 = new Gtk.HSeparator();
            this.hseparator7.WidthRequest = 47;
            this.hseparator7.Name = "hseparator7";
            this.pnlLowerScore.Add(this.hseparator7);
            Gtk.Table.TableChild w204 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.hseparator7]));
            w204.LeftAttach = ((uint)(5));
            w204.RightAttach = ((uint)(6));
            w204.XOptions = ((Gtk.AttachOptions)(4));
            w204.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.hseparator8 = new Gtk.HSeparator();
            this.hseparator8.Name = "hseparator8";
            this.pnlLowerScore.Add(this.hseparator8);
            Gtk.Table.TableChild w205 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.hseparator8]));
            w205.LeftAttach = ((uint)(1));
            w205.RightAttach = ((uint)(2));
            w205.XOptions = ((Gtk.AttachOptions)(4));
            w205.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.hseparator9 = new Gtk.HSeparator();
            this.hseparator9.Name = "hseparator9";
            this.pnlLowerScore.Add(this.hseparator9);
            Gtk.Table.TableChild w206 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.hseparator9]));
            w206.XOptions = ((Gtk.AttachOptions)(4));
            w206.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r10c1 = new Gtk.Frame();
            this.r10c1.Name = "r10c1";
            // Container child r10c1.Gtk.Container+ContainerChild
            this.btnr10c1 = new Gtk.Button();
            this.btnr10c1.WidthRequest = 30;
            this.btnr10c1.HeightRequest = 27;
            this.btnr10c1.CanFocus = true;
            this.btnr10c1.Name = "btnr10c1";
            this.btnr10c1.UseUnderline = true;
            this.btnr10c1.FocusOnClick = false;
            this.btnr10c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr10c1.Label = "";
            this.r10c1.Add(this.btnr10c1);
            this.pnlLowerScore.Add(this.r10c1);
            Gtk.Table.TableChild w208 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r10c1]));
            w208.TopAttach = ((uint)(2));
            w208.BottomAttach = ((uint)(3));
            w208.LeftAttach = ((uint)(2));
            w208.RightAttach = ((uint)(3));
            w208.XOptions = ((Gtk.AttachOptions)(4));
            w208.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r10c2 = new Gtk.Frame();
            this.r10c2.Name = "r10c2";
            // Container child r10c2.Gtk.Container+ContainerChild
            this.btnr10c2 = new Gtk.Button();
            this.btnr10c2.WidthRequest = 30;
            this.btnr10c2.HeightRequest = 27;
            this.btnr10c2.CanFocus = true;
            this.btnr10c2.Name = "btnr10c2";
            this.btnr10c2.UseUnderline = true;
            this.btnr10c2.FocusOnClick = false;
            this.btnr10c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr10c2.Label = "";
            this.r10c2.Add(this.btnr10c2);
            this.pnlLowerScore.Add(this.r10c2);
            Gtk.Table.TableChild w210 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r10c2]));
            w210.TopAttach = ((uint)(2));
            w210.BottomAttach = ((uint)(3));
            w210.LeftAttach = ((uint)(3));
            w210.RightAttach = ((uint)(4));
            w210.XOptions = ((Gtk.AttachOptions)(4));
            w210.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r10c3 = new Gtk.Frame();
            this.r10c3.Name = "r10c3";
            // Container child r10c3.Gtk.Container+ContainerChild
            this.btnr10c3 = new Gtk.Button();
            this.btnr10c3.WidthRequest = 30;
            this.btnr10c3.HeightRequest = 27;
            this.btnr10c3.CanFocus = true;
            this.btnr10c3.Name = "btnr10c3";
            this.btnr10c3.UseUnderline = true;
            this.btnr10c3.FocusOnClick = false;
            this.btnr10c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr10c3.Label = "";
            this.r10c3.Add(this.btnr10c3);
            this.pnlLowerScore.Add(this.r10c3);
            Gtk.Table.TableChild w212 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r10c3]));
            w212.TopAttach = ((uint)(2));
            w212.BottomAttach = ((uint)(3));
            w212.LeftAttach = ((uint)(4));
            w212.RightAttach = ((uint)(5));
            w212.XOptions = ((Gtk.AttachOptions)(4));
            w212.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r10c4 = new Gtk.Frame();
            this.r10c4.Name = "r10c4";
            // Container child r10c4.Gtk.Container+ContainerChild
            this.btnr10c4 = new Gtk.Button();
            this.btnr10c4.WidthRequest = 30;
            this.btnr10c4.HeightRequest = 27;
            this.btnr10c4.CanFocus = true;
            this.btnr10c4.Name = "btnr10c4";
            this.btnr10c4.UseUnderline = true;
            this.btnr10c4.FocusOnClick = false;
            this.btnr10c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr10c4.Label = "";
            this.r10c4.Add(this.btnr10c4);
            this.pnlLowerScore.Add(this.r10c4);
            Gtk.Table.TableChild w214 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r10c4]));
            w214.TopAttach = ((uint)(2));
            w214.BottomAttach = ((uint)(3));
            w214.LeftAttach = ((uint)(5));
            w214.RightAttach = ((uint)(6));
            w214.XOptions = ((Gtk.AttachOptions)(4));
            w214.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r10c5 = new Gtk.Frame();
            this.r10c5.Name = "r10c5";
            // Container child r10c5.Gtk.Container+ContainerChild
            this.btnr10c5 = new Gtk.Button();
            this.btnr10c5.WidthRequest = 30;
            this.btnr10c5.HeightRequest = 27;
            this.btnr10c5.CanFocus = true;
            this.btnr10c5.Name = "btnr10c5";
            this.btnr10c5.UseUnderline = true;
            this.btnr10c5.FocusOnClick = false;
            this.btnr10c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr10c5.Label = "";
            this.r10c5.Add(this.btnr10c5);
            this.pnlLowerScore.Add(this.r10c5);
            Gtk.Table.TableChild w216 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r10c5]));
            w216.TopAttach = ((uint)(2));
            w216.BottomAttach = ((uint)(3));
            w216.LeftAttach = ((uint)(6));
            w216.RightAttach = ((uint)(7));
            w216.XOptions = ((Gtk.AttachOptions)(4));
            w216.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r11c1 = new Gtk.Frame();
            this.r11c1.Name = "r11c1";
            // Container child r11c1.Gtk.Container+ContainerChild
            this.btnr11c1 = new Gtk.Button();
            this.btnr11c1.WidthRequest = 30;
            this.btnr11c1.HeightRequest = 27;
            this.btnr11c1.CanFocus = true;
            this.btnr11c1.Name = "btnr11c1";
            this.btnr11c1.UseUnderline = true;
            this.btnr11c1.FocusOnClick = false;
            this.btnr11c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr11c1.Label = "";
            this.r11c1.Add(this.btnr11c1);
            this.pnlLowerScore.Add(this.r11c1);
            Gtk.Table.TableChild w218 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r11c1]));
            w218.TopAttach = ((uint)(3));
            w218.BottomAttach = ((uint)(4));
            w218.LeftAttach = ((uint)(2));
            w218.RightAttach = ((uint)(3));
            w218.XOptions = ((Gtk.AttachOptions)(4));
            w218.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r11c2 = new Gtk.Frame();
            this.r11c2.Name = "r11c2";
            // Container child r11c2.Gtk.Container+ContainerChild
            this.btnr11c2 = new Gtk.Button();
            this.btnr11c2.WidthRequest = 30;
            this.btnr11c2.HeightRequest = 27;
            this.btnr11c2.CanFocus = true;
            this.btnr11c2.Name = "btnr11c2";
            this.btnr11c2.UseUnderline = true;
            this.btnr11c2.FocusOnClick = false;
            this.btnr11c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr11c2.Label = "";
            this.r11c2.Add(this.btnr11c2);
            this.pnlLowerScore.Add(this.r11c2);
            Gtk.Table.TableChild w220 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r11c2]));
            w220.TopAttach = ((uint)(3));
            w220.BottomAttach = ((uint)(4));
            w220.LeftAttach = ((uint)(3));
            w220.RightAttach = ((uint)(4));
            w220.XOptions = ((Gtk.AttachOptions)(4));
            w220.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r11c3 = new Gtk.Frame();
            this.r11c3.Name = "r11c3";
            // Container child r11c3.Gtk.Container+ContainerChild
            this.btnr11c3 = new Gtk.Button();
            this.btnr11c3.WidthRequest = 30;
            this.btnr11c3.HeightRequest = 27;
            this.btnr11c3.CanFocus = true;
            this.btnr11c3.Name = "btnr11c3";
            this.btnr11c3.UseUnderline = true;
            this.btnr11c3.FocusOnClick = false;
            this.btnr11c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr11c3.Label = "";
            this.r11c3.Add(this.btnr11c3);
            this.pnlLowerScore.Add(this.r11c3);
            Gtk.Table.TableChild w222 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r11c3]));
            w222.TopAttach = ((uint)(3));
            w222.BottomAttach = ((uint)(4));
            w222.LeftAttach = ((uint)(4));
            w222.RightAttach = ((uint)(5));
            w222.XOptions = ((Gtk.AttachOptions)(4));
            w222.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r11c4 = new Gtk.Frame();
            this.r11c4.Name = "r11c4";
            // Container child r11c4.Gtk.Container+ContainerChild
            this.btnr11c4 = new Gtk.Button();
            this.btnr11c4.WidthRequest = 30;
            this.btnr11c4.HeightRequest = 27;
            this.btnr11c4.CanFocus = true;
            this.btnr11c4.Name = "btnr11c4";
            this.btnr11c4.UseUnderline = true;
            this.btnr11c4.FocusOnClick = false;
            this.btnr11c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr11c4.Label = "";
            this.r11c4.Add(this.btnr11c4);
            this.pnlLowerScore.Add(this.r11c4);
            Gtk.Table.TableChild w224 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r11c4]));
            w224.TopAttach = ((uint)(3));
            w224.BottomAttach = ((uint)(4));
            w224.LeftAttach = ((uint)(5));
            w224.RightAttach = ((uint)(6));
            w224.XOptions = ((Gtk.AttachOptions)(4));
            w224.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r11c5 = new Gtk.Frame();
            this.r11c5.Name = "r11c5";
            // Container child r11c5.Gtk.Container+ContainerChild
            this.btnr11c5 = new Gtk.Button();
            this.btnr11c5.WidthRequest = 30;
            this.btnr11c5.HeightRequest = 27;
            this.btnr11c5.CanFocus = true;
            this.btnr11c5.Name = "btnr11c5";
            this.btnr11c5.UseUnderline = true;
            this.btnr11c5.FocusOnClick = false;
            this.btnr11c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr11c5.Label = "";
            this.r11c5.Add(this.btnr11c5);
            this.pnlLowerScore.Add(this.r11c5);
            Gtk.Table.TableChild w226 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r11c5]));
            w226.TopAttach = ((uint)(3));
            w226.BottomAttach = ((uint)(4));
            w226.LeftAttach = ((uint)(6));
            w226.RightAttach = ((uint)(7));
            w226.XOptions = ((Gtk.AttachOptions)(4));
            w226.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r12c1 = new Gtk.Frame();
            this.r12c1.Name = "r12c1";
            // Container child r12c1.Gtk.Container+ContainerChild
            this.btnr12c1 = new Gtk.Button();
            this.btnr12c1.WidthRequest = 30;
            this.btnr12c1.HeightRequest = 27;
            this.btnr12c1.CanFocus = true;
            this.btnr12c1.Name = "btnr12c1";
            this.btnr12c1.UseUnderline = true;
            this.btnr12c1.FocusOnClick = false;
            this.btnr12c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr12c1.Label = "";
            this.r12c1.Add(this.btnr12c1);
            this.pnlLowerScore.Add(this.r12c1);
            Gtk.Table.TableChild w228 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r12c1]));
            w228.TopAttach = ((uint)(4));
            w228.BottomAttach = ((uint)(5));
            w228.LeftAttach = ((uint)(2));
            w228.RightAttach = ((uint)(3));
            w228.XOptions = ((Gtk.AttachOptions)(4));
            w228.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r12c2 = new Gtk.Frame();
            this.r12c2.Name = "r12c2";
            // Container child r12c2.Gtk.Container+ContainerChild
            this.btnr12c2 = new Gtk.Button();
            this.btnr12c2.WidthRequest = 30;
            this.btnr12c2.HeightRequest = 27;
            this.btnr12c2.CanFocus = true;
            this.btnr12c2.Name = "btnr12c2";
            this.btnr12c2.UseUnderline = true;
            this.btnr12c2.FocusOnClick = false;
            this.btnr12c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr12c2.Label = "";
            this.r12c2.Add(this.btnr12c2);
            this.pnlLowerScore.Add(this.r12c2);
            Gtk.Table.TableChild w230 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r12c2]));
            w230.TopAttach = ((uint)(4));
            w230.BottomAttach = ((uint)(5));
            w230.LeftAttach = ((uint)(3));
            w230.RightAttach = ((uint)(4));
            w230.XOptions = ((Gtk.AttachOptions)(4));
            w230.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r12c3 = new Gtk.Frame();
            this.r12c3.Name = "r12c3";
            // Container child r12c3.Gtk.Container+ContainerChild
            this.btnr12c3 = new Gtk.Button();
            this.btnr12c3.WidthRequest = 30;
            this.btnr12c3.HeightRequest = 27;
            this.btnr12c3.CanFocus = true;
            this.btnr12c3.Name = "btnr12c3";
            this.btnr12c3.UseUnderline = true;
            this.btnr12c3.FocusOnClick = false;
            this.btnr12c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr12c3.Label = "";
            this.r12c3.Add(this.btnr12c3);
            this.pnlLowerScore.Add(this.r12c3);
            Gtk.Table.TableChild w232 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r12c3]));
            w232.TopAttach = ((uint)(4));
            w232.BottomAttach = ((uint)(5));
            w232.LeftAttach = ((uint)(4));
            w232.RightAttach = ((uint)(5));
            w232.XOptions = ((Gtk.AttachOptions)(4));
            w232.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r12c4 = new Gtk.Frame();
            this.r12c4.Name = "r12c4";
            // Container child r12c4.Gtk.Container+ContainerChild
            this.btnr12c4 = new Gtk.Button();
            this.btnr12c4.WidthRequest = 30;
            this.btnr12c4.HeightRequest = 27;
            this.btnr12c4.CanFocus = true;
            this.btnr12c4.Name = "btnr12c4";
            this.btnr12c4.UseUnderline = true;
            this.btnr12c4.FocusOnClick = false;
            this.btnr12c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr12c4.Label = "";
            this.r12c4.Add(this.btnr12c4);
            this.pnlLowerScore.Add(this.r12c4);
            Gtk.Table.TableChild w234 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r12c4]));
            w234.TopAttach = ((uint)(4));
            w234.BottomAttach = ((uint)(5));
            w234.LeftAttach = ((uint)(5));
            w234.RightAttach = ((uint)(6));
            w234.XOptions = ((Gtk.AttachOptions)(4));
            w234.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r12c5 = new Gtk.Frame();
            this.r12c5.Name = "r12c5";
            // Container child r12c5.Gtk.Container+ContainerChild
            this.btnr12c5 = new Gtk.Button();
            this.btnr12c5.WidthRequest = 30;
            this.btnr12c5.HeightRequest = 27;
            this.btnr12c5.CanFocus = true;
            this.btnr12c5.Name = "btnr12c5";
            this.btnr12c5.UseUnderline = true;
            this.btnr12c5.FocusOnClick = false;
            this.btnr12c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr12c5.Label = "";
            this.r12c5.Add(this.btnr12c5);
            this.pnlLowerScore.Add(this.r12c5);
            Gtk.Table.TableChild w236 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r12c5]));
            w236.TopAttach = ((uint)(4));
            w236.BottomAttach = ((uint)(5));
            w236.LeftAttach = ((uint)(6));
            w236.RightAttach = ((uint)(7));
            w236.XOptions = ((Gtk.AttachOptions)(4));
            w236.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r13c1 = new Gtk.Frame();
            this.r13c1.Name = "r13c1";
            // Container child r13c1.Gtk.Container+ContainerChild
            this.btnr13c1 = new Gtk.Button();
            this.btnr13c1.WidthRequest = 30;
            this.btnr13c1.HeightRequest = 27;
            this.btnr13c1.CanFocus = true;
            this.btnr13c1.Name = "btnr13c1";
            this.btnr13c1.UseUnderline = true;
            this.btnr13c1.FocusOnClick = false;
            this.btnr13c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr13c1.Label = "";
            this.r13c1.Add(this.btnr13c1);
            this.pnlLowerScore.Add(this.r13c1);
            Gtk.Table.TableChild w238 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r13c1]));
            w238.TopAttach = ((uint)(5));
            w238.BottomAttach = ((uint)(6));
            w238.LeftAttach = ((uint)(2));
            w238.RightAttach = ((uint)(3));
            w238.XOptions = ((Gtk.AttachOptions)(4));
            w238.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r13c2 = new Gtk.Frame();
            this.r13c2.Name = "r13c2";
            // Container child r13c2.Gtk.Container+ContainerChild
            this.btnr13c2 = new Gtk.Button();
            this.btnr13c2.WidthRequest = 30;
            this.btnr13c2.HeightRequest = 27;
            this.btnr13c2.CanFocus = true;
            this.btnr13c2.Name = "btnr13c2";
            this.btnr13c2.UseUnderline = true;
            this.btnr13c2.FocusOnClick = false;
            this.btnr13c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr13c2.Label = "";
            this.r13c2.Add(this.btnr13c2);
            this.pnlLowerScore.Add(this.r13c2);
            Gtk.Table.TableChild w240 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r13c2]));
            w240.TopAttach = ((uint)(5));
            w240.BottomAttach = ((uint)(6));
            w240.LeftAttach = ((uint)(3));
            w240.RightAttach = ((uint)(4));
            w240.XOptions = ((Gtk.AttachOptions)(4));
            w240.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r13c3 = new Gtk.Frame();
            this.r13c3.Name = "r13c3";
            // Container child r13c3.Gtk.Container+ContainerChild
            this.btnr13c3 = new Gtk.Button();
            this.btnr13c3.WidthRequest = 30;
            this.btnr13c3.HeightRequest = 27;
            this.btnr13c3.CanFocus = true;
            this.btnr13c3.Name = "btnr13c3";
            this.btnr13c3.UseUnderline = true;
            this.btnr13c3.FocusOnClick = false;
            this.btnr13c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr13c3.Label = "";
            this.r13c3.Add(this.btnr13c3);
            this.pnlLowerScore.Add(this.r13c3);
            Gtk.Table.TableChild w242 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r13c3]));
            w242.TopAttach = ((uint)(5));
            w242.BottomAttach = ((uint)(6));
            w242.LeftAttach = ((uint)(4));
            w242.RightAttach = ((uint)(5));
            w242.XOptions = ((Gtk.AttachOptions)(4));
            w242.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r13c4 = new Gtk.Frame();
            this.r13c4.Name = "r13c4";
            // Container child r13c4.Gtk.Container+ContainerChild
            this.btnr13c4 = new Gtk.Button();
            this.btnr13c4.WidthRequest = 30;
            this.btnr13c4.HeightRequest = 27;
            this.btnr13c4.CanFocus = true;
            this.btnr13c4.Name = "btnr13c4";
            this.btnr13c4.UseUnderline = true;
            this.btnr13c4.FocusOnClick = false;
            this.btnr13c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr13c4.Label = "";
            this.r13c4.Add(this.btnr13c4);
            this.pnlLowerScore.Add(this.r13c4);
            Gtk.Table.TableChild w244 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r13c4]));
            w244.TopAttach = ((uint)(5));
            w244.BottomAttach = ((uint)(6));
            w244.LeftAttach = ((uint)(5));
            w244.RightAttach = ((uint)(6));
            w244.XOptions = ((Gtk.AttachOptions)(4));
            w244.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r13c5 = new Gtk.Frame();
            this.r13c5.Name = "r13c5";
            // Container child r13c5.Gtk.Container+ContainerChild
            this.btnr13c5 = new Gtk.Button();
            this.btnr13c5.WidthRequest = 30;
            this.btnr13c5.HeightRequest = 27;
            this.btnr13c5.CanFocus = true;
            this.btnr13c5.Name = "btnr13c5";
            this.btnr13c5.UseUnderline = true;
            this.btnr13c5.FocusOnClick = false;
            this.btnr13c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr13c5.Label = "";
            this.r13c5.Add(this.btnr13c5);
            this.pnlLowerScore.Add(this.r13c5);
            Gtk.Table.TableChild w246 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r13c5]));
            w246.TopAttach = ((uint)(5));
            w246.BottomAttach = ((uint)(6));
            w246.LeftAttach = ((uint)(6));
            w246.RightAttach = ((uint)(7));
            w246.XOptions = ((Gtk.AttachOptions)(4));
            w246.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r14c1 = new Gtk.Frame();
            this.r14c1.Name = "r14c1";
            // Container child r14c1.Gtk.Container+ContainerChild
            this.btnr14c1 = new Gtk.Button();
            this.btnr14c1.WidthRequest = 30;
            this.btnr14c1.HeightRequest = 27;
            this.btnr14c1.CanFocus = true;
            this.btnr14c1.Name = "btnr14c1";
            this.btnr14c1.UseUnderline = true;
            this.btnr14c1.FocusOnClick = false;
            this.btnr14c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr14c1.Label = "";
            this.r14c1.Add(this.btnr14c1);
            this.pnlLowerScore.Add(this.r14c1);
            Gtk.Table.TableChild w248 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r14c1]));
            w248.TopAttach = ((uint)(6));
            w248.BottomAttach = ((uint)(7));
            w248.LeftAttach = ((uint)(2));
            w248.RightAttach = ((uint)(3));
            w248.XOptions = ((Gtk.AttachOptions)(4));
            w248.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r14c2 = new Gtk.Frame();
            this.r14c2.Name = "r14c2";
            // Container child r14c2.Gtk.Container+ContainerChild
            this.btnr14c2 = new Gtk.Button();
            this.btnr14c2.WidthRequest = 30;
            this.btnr14c2.HeightRequest = 27;
            this.btnr14c2.CanFocus = true;
            this.btnr14c2.Name = "btnr14c2";
            this.btnr14c2.UseUnderline = true;
            this.btnr14c2.FocusOnClick = false;
            this.btnr14c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr14c2.Label = "";
            this.r14c2.Add(this.btnr14c2);
            this.pnlLowerScore.Add(this.r14c2);
            Gtk.Table.TableChild w250 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r14c2]));
            w250.TopAttach = ((uint)(6));
            w250.BottomAttach = ((uint)(7));
            w250.LeftAttach = ((uint)(3));
            w250.RightAttach = ((uint)(4));
            w250.XOptions = ((Gtk.AttachOptions)(4));
            w250.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r14c3 = new Gtk.Frame();
            this.r14c3.Name = "r14c3";
            // Container child r14c3.Gtk.Container+ContainerChild
            this.btnr14c3 = new Gtk.Button();
            this.btnr14c3.WidthRequest = 30;
            this.btnr14c3.HeightRequest = 27;
            this.btnr14c3.CanFocus = true;
            this.btnr14c3.Name = "btnr14c3";
            this.btnr14c3.UseUnderline = true;
            this.btnr14c3.FocusOnClick = false;
            this.btnr14c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr14c3.Label = "";
            this.r14c3.Add(this.btnr14c3);
            this.pnlLowerScore.Add(this.r14c3);
            Gtk.Table.TableChild w252 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r14c3]));
            w252.TopAttach = ((uint)(6));
            w252.BottomAttach = ((uint)(7));
            w252.LeftAttach = ((uint)(4));
            w252.RightAttach = ((uint)(5));
            w252.XOptions = ((Gtk.AttachOptions)(4));
            w252.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r14c4 = new Gtk.Frame();
            this.r14c4.Name = "r14c4";
            // Container child r14c4.Gtk.Container+ContainerChild
            this.btnr14c4 = new Gtk.Button();
            this.btnr14c4.WidthRequest = 30;
            this.btnr14c4.HeightRequest = 27;
            this.btnr14c4.CanFocus = true;
            this.btnr14c4.Name = "btnr14c4";
            this.btnr14c4.UseUnderline = true;
            this.btnr14c4.FocusOnClick = false;
            this.btnr14c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr14c4.Label = "";
            this.r14c4.Add(this.btnr14c4);
            this.pnlLowerScore.Add(this.r14c4);
            Gtk.Table.TableChild w254 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r14c4]));
            w254.TopAttach = ((uint)(6));
            w254.BottomAttach = ((uint)(7));
            w254.LeftAttach = ((uint)(5));
            w254.RightAttach = ((uint)(6));
            w254.XOptions = ((Gtk.AttachOptions)(4));
            w254.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r14c5 = new Gtk.Frame();
            this.r14c5.Name = "r14c5";
            // Container child r14c5.Gtk.Container+ContainerChild
            this.btnr14c5 = new Gtk.Button();
            this.btnr14c5.WidthRequest = 30;
            this.btnr14c5.HeightRequest = 27;
            this.btnr14c5.CanFocus = true;
            this.btnr14c5.Name = "btnr14c5";
            this.btnr14c5.UseUnderline = true;
            this.btnr14c5.FocusOnClick = false;
            this.btnr14c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr14c5.Label = "";
            this.r14c5.Add(this.btnr14c5);
            this.pnlLowerScore.Add(this.r14c5);
            Gtk.Table.TableChild w256 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r14c5]));
            w256.TopAttach = ((uint)(6));
            w256.BottomAttach = ((uint)(7));
            w256.LeftAttach = ((uint)(6));
            w256.RightAttach = ((uint)(7));
            w256.XOptions = ((Gtk.AttachOptions)(4));
            w256.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r15c1 = new Gtk.Frame();
            this.r15c1.Name = "r15c1";
            // Container child r15c1.Gtk.Container+ContainerChild
            this.btnr15c1 = new Gtk.Button();
            this.btnr15c1.WidthRequest = 30;
            this.btnr15c1.HeightRequest = 27;
            this.btnr15c1.CanFocus = true;
            this.btnr15c1.Name = "btnr15c1";
            this.btnr15c1.UseUnderline = true;
            this.btnr15c1.FocusOnClick = false;
            this.btnr15c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr15c1.Label = "";
            this.r15c1.Add(this.btnr15c1);
            this.pnlLowerScore.Add(this.r15c1);
            Gtk.Table.TableChild w258 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r15c1]));
            w258.TopAttach = ((uint)(7));
            w258.BottomAttach = ((uint)(8));
            w258.LeftAttach = ((uint)(2));
            w258.RightAttach = ((uint)(3));
            w258.XOptions = ((Gtk.AttachOptions)(4));
            w258.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r15c2 = new Gtk.Frame();
            this.r15c2.Name = "r15c2";
            // Container child r15c2.Gtk.Container+ContainerChild
            this.btnr15c2 = new Gtk.Button();
            this.btnr15c2.WidthRequest = 30;
            this.btnr15c2.HeightRequest = 27;
            this.btnr15c2.CanFocus = true;
            this.btnr15c2.Name = "btnr15c2";
            this.btnr15c2.UseUnderline = true;
            this.btnr15c2.FocusOnClick = false;
            this.btnr15c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr15c2.Label = "";
            this.r15c2.Add(this.btnr15c2);
            this.pnlLowerScore.Add(this.r15c2);
            Gtk.Table.TableChild w260 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r15c2]));
            w260.TopAttach = ((uint)(7));
            w260.BottomAttach = ((uint)(8));
            w260.LeftAttach = ((uint)(3));
            w260.RightAttach = ((uint)(4));
            w260.XOptions = ((Gtk.AttachOptions)(4));
            w260.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r15c3 = new Gtk.Frame();
            this.r15c3.Name = "r15c3";
            // Container child r15c3.Gtk.Container+ContainerChild
            this.btnr15c3 = new Gtk.Button();
            this.btnr15c3.WidthRequest = 30;
            this.btnr15c3.HeightRequest = 27;
            this.btnr15c3.CanFocus = true;
            this.btnr15c3.Name = "btnr15c3";
            this.btnr15c3.UseUnderline = true;
            this.btnr15c3.FocusOnClick = false;
            this.btnr15c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr15c3.Label = "";
            this.r15c3.Add(this.btnr15c3);
            this.pnlLowerScore.Add(this.r15c3);
            Gtk.Table.TableChild w262 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r15c3]));
            w262.TopAttach = ((uint)(7));
            w262.BottomAttach = ((uint)(8));
            w262.LeftAttach = ((uint)(4));
            w262.RightAttach = ((uint)(5));
            w262.XOptions = ((Gtk.AttachOptions)(4));
            w262.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r15c4 = new Gtk.Frame();
            this.r15c4.Name = "r15c4";
            // Container child r15c4.Gtk.Container+ContainerChild
            this.btnr15c4 = new Gtk.Button();
            this.btnr15c4.WidthRequest = 30;
            this.btnr15c4.HeightRequest = 27;
            this.btnr15c4.CanFocus = true;
            this.btnr15c4.Name = "btnr15c4";
            this.btnr15c4.UseUnderline = true;
            this.btnr15c4.FocusOnClick = false;
            this.btnr15c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr15c4.Label = "";
            this.r15c4.Add(this.btnr15c4);
            this.pnlLowerScore.Add(this.r15c4);
            Gtk.Table.TableChild w264 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r15c4]));
            w264.TopAttach = ((uint)(7));
            w264.BottomAttach = ((uint)(8));
            w264.LeftAttach = ((uint)(5));
            w264.RightAttach = ((uint)(6));
            w264.XOptions = ((Gtk.AttachOptions)(4));
            w264.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r15c5 = new Gtk.Frame();
            this.r15c5.Name = "r15c5";
            // Container child r15c5.Gtk.Container+ContainerChild
            this.btnr15c5 = new Gtk.Button();
            this.btnr15c5.WidthRequest = 30;
            this.btnr15c5.HeightRequest = 27;
            this.btnr15c5.CanFocus = true;
            this.btnr15c5.Name = "btnr15c5";
            this.btnr15c5.UseUnderline = true;
            this.btnr15c5.FocusOnClick = false;
            this.btnr15c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr15c5.Label = "";
            this.r15c5.Add(this.btnr15c5);
            this.pnlLowerScore.Add(this.r15c5);
            Gtk.Table.TableChild w266 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r15c5]));
            w266.TopAttach = ((uint)(7));
            w266.BottomAttach = ((uint)(8));
            w266.LeftAttach = ((uint)(6));
            w266.RightAttach = ((uint)(7));
            w266.XOptions = ((Gtk.AttachOptions)(4));
            w266.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r16c1 = new Gtk.Frame();
            this.r16c1.Name = "r16c1";
            // Container child r16c1.Gtk.Container+ContainerChild
            this.btnr16c1 = new Gtk.Button();
            this.btnr16c1.WidthRequest = 30;
            this.btnr16c1.HeightRequest = 27;
            this.btnr16c1.CanFocus = true;
            this.btnr16c1.Name = "btnr16c1";
            this.btnr16c1.UseUnderline = true;
            this.btnr16c1.FocusOnClick = false;
            this.btnr16c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr16c1.Label = "";
            this.r16c1.Add(this.btnr16c1);
            this.pnlLowerScore.Add(this.r16c1);
            Gtk.Table.TableChild w268 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r16c1]));
            w268.TopAttach = ((uint)(8));
            w268.BottomAttach = ((uint)(9));
            w268.LeftAttach = ((uint)(2));
            w268.RightAttach = ((uint)(3));
            w268.XOptions = ((Gtk.AttachOptions)(4));
            w268.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r16c2 = new Gtk.Frame();
            this.r16c2.Name = "r16c2";
            // Container child r16c2.Gtk.Container+ContainerChild
            this.btnr16c2 = new Gtk.Button();
            this.btnr16c2.WidthRequest = 30;
            this.btnr16c2.HeightRequest = 27;
            this.btnr16c2.CanFocus = true;
            this.btnr16c2.Name = "btnr16c2";
            this.btnr16c2.UseUnderline = true;
            this.btnr16c2.FocusOnClick = false;
            this.btnr16c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr16c2.Label = "";
            this.r16c2.Add(this.btnr16c2);
            this.pnlLowerScore.Add(this.r16c2);
            Gtk.Table.TableChild w270 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r16c2]));
            w270.TopAttach = ((uint)(8));
            w270.BottomAttach = ((uint)(9));
            w270.LeftAttach = ((uint)(3));
            w270.RightAttach = ((uint)(4));
            w270.XOptions = ((Gtk.AttachOptions)(4));
            w270.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r16c3 = new Gtk.Frame();
            this.r16c3.Name = "r16c3";
            // Container child r16c3.Gtk.Container+ContainerChild
            this.btnr16c3 = new Gtk.Button();
            this.btnr16c3.WidthRequest = 30;
            this.btnr16c3.HeightRequest = 27;
            this.btnr16c3.CanFocus = true;
            this.btnr16c3.Name = "btnr16c3";
            this.btnr16c3.UseUnderline = true;
            this.btnr16c3.FocusOnClick = false;
            this.btnr16c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr16c3.Label = "";
            this.r16c3.Add(this.btnr16c3);
            this.pnlLowerScore.Add(this.r16c3);
            Gtk.Table.TableChild w272 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r16c3]));
            w272.TopAttach = ((uint)(8));
            w272.BottomAttach = ((uint)(9));
            w272.LeftAttach = ((uint)(4));
            w272.RightAttach = ((uint)(5));
            w272.XOptions = ((Gtk.AttachOptions)(4));
            w272.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r16c4 = new Gtk.Frame();
            this.r16c4.Name = "r16c4";
            // Container child r16c4.Gtk.Container+ContainerChild
            this.btnr16c4 = new Gtk.Button();
            this.btnr16c4.WidthRequest = 30;
            this.btnr16c4.HeightRequest = 27;
            this.btnr16c4.CanFocus = true;
            this.btnr16c4.Name = "btnr16c4";
            this.btnr16c4.UseUnderline = true;
            this.btnr16c4.FocusOnClick = false;
            this.btnr16c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr16c4.Label = "";
            this.r16c4.Add(this.btnr16c4);
            this.pnlLowerScore.Add(this.r16c4);
            Gtk.Table.TableChild w274 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r16c4]));
            w274.TopAttach = ((uint)(8));
            w274.BottomAttach = ((uint)(9));
            w274.LeftAttach = ((uint)(5));
            w274.RightAttach = ((uint)(6));
            w274.XOptions = ((Gtk.AttachOptions)(4));
            w274.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r16c5 = new Gtk.Frame();
            this.r16c5.Name = "r16c5";
            // Container child r16c5.Gtk.Container+ContainerChild
            this.btnr16c5 = new Gtk.Button();
            this.btnr16c5.WidthRequest = 30;
            this.btnr16c5.HeightRequest = 27;
            this.btnr16c5.CanFocus = true;
            this.btnr16c5.Name = "btnr16c5";
            this.btnr16c5.UseUnderline = true;
            this.btnr16c5.FocusOnClick = false;
            this.btnr16c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr16c5.Label = "";
            this.r16c5.Add(this.btnr16c5);
            this.pnlLowerScore.Add(this.r16c5);
            Gtk.Table.TableChild w276 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r16c5]));
            w276.TopAttach = ((uint)(8));
            w276.BottomAttach = ((uint)(9));
            w276.LeftAttach = ((uint)(6));
            w276.RightAttach = ((uint)(7));
            w276.XOptions = ((Gtk.AttachOptions)(4));
            w276.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r17c1 = new Gtk.Frame();
            this.r17c1.Name = "r17c1";
            // Container child r17c1.Gtk.Container+ContainerChild
            this.btnr17c1 = new Gtk.Label();
            this.btnr17c1.Name = "btnr17c1";
            this.btnr17c1.Justify = ((Gtk.Justification)(2));
            this.r17c1.Add(this.btnr17c1);
            this.pnlLowerScore.Add(this.r17c1);
            Gtk.Table.TableChild w278 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r17c1]));
            w278.TopAttach = ((uint)(9));
            w278.BottomAttach = ((uint)(10));
            w278.LeftAttach = ((uint)(2));
            w278.RightAttach = ((uint)(3));
            w278.XOptions = ((Gtk.AttachOptions)(4));
            w278.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r17c2 = new Gtk.Frame();
            this.r17c2.Name = "r17c2";
            // Container child r17c2.Gtk.Container+ContainerChild
            this.btnr17c2 = new Gtk.Label();
            this.btnr17c2.Name = "btnr17c2";
            this.btnr17c2.Justify = ((Gtk.Justification)(2));
            this.r17c2.Add(this.btnr17c2);
            this.pnlLowerScore.Add(this.r17c2);
            Gtk.Table.TableChild w280 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r17c2]));
            w280.TopAttach = ((uint)(9));
            w280.BottomAttach = ((uint)(10));
            w280.LeftAttach = ((uint)(3));
            w280.RightAttach = ((uint)(4));
            w280.XOptions = ((Gtk.AttachOptions)(4));
            w280.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r17c3 = new Gtk.Frame();
            this.r17c3.Name = "r17c3";
            // Container child r17c3.Gtk.Container+ContainerChild
            this.btnr17c3 = new Gtk.Label();
            this.btnr17c3.Name = "btnr17c3";
            this.btnr17c3.Justify = ((Gtk.Justification)(2));
            this.r17c3.Add(this.btnr17c3);
            this.pnlLowerScore.Add(this.r17c3);
            Gtk.Table.TableChild w282 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r17c3]));
            w282.TopAttach = ((uint)(9));
            w282.BottomAttach = ((uint)(10));
            w282.LeftAttach = ((uint)(4));
            w282.RightAttach = ((uint)(5));
            w282.XOptions = ((Gtk.AttachOptions)(4));
            w282.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r17c4 = new Gtk.Frame();
            this.r17c4.Name = "r17c4";
            // Container child r17c4.Gtk.Container+ContainerChild
            this.btnr17c4 = new Gtk.Label();
            this.btnr17c4.Name = "btnr17c4";
            this.btnr17c4.Justify = ((Gtk.Justification)(2));
            this.r17c4.Add(this.btnr17c4);
            this.pnlLowerScore.Add(this.r17c4);
            Gtk.Table.TableChild w284 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r17c4]));
            w284.TopAttach = ((uint)(9));
            w284.BottomAttach = ((uint)(10));
            w284.LeftAttach = ((uint)(5));
            w284.RightAttach = ((uint)(6));
            w284.XOptions = ((Gtk.AttachOptions)(4));
            w284.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r17c5 = new Gtk.Frame();
            this.r17c5.Name = "r17c5";
            // Container child r17c5.Gtk.Container+ContainerChild
            this.btnr17c5 = new Gtk.Label();
            this.btnr17c5.Name = "btnr17c5";
            this.btnr17c5.Justify = ((Gtk.Justification)(2));
            this.r17c5.Add(this.btnr17c5);
            this.pnlLowerScore.Add(this.r17c5);
            Gtk.Table.TableChild w286 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r17c5]));
            w286.TopAttach = ((uint)(9));
            w286.BottomAttach = ((uint)(10));
            w286.LeftAttach = ((uint)(6));
            w286.RightAttach = ((uint)(7));
            w286.XOptions = ((Gtk.AttachOptions)(4));
            w286.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r18c1 = new Gtk.Frame();
            this.r18c1.Name = "r18c1";
            // Container child r18c1.Gtk.Container+ContainerChild
            this.rbtn18c1 = new Gtk.Label();
            this.rbtn18c1.Name = "rbtn18c1";
            this.rbtn18c1.Justify = ((Gtk.Justification)(2));
            this.r18c1.Add(this.rbtn18c1);
            this.pnlLowerScore.Add(this.r18c1);
            Gtk.Table.TableChild w288 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r18c1]));
            w288.TopAttach = ((uint)(10));
            w288.BottomAttach = ((uint)(11));
            w288.LeftAttach = ((uint)(2));
            w288.RightAttach = ((uint)(3));
            w288.XOptions = ((Gtk.AttachOptions)(4));
            w288.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r18c2 = new Gtk.Frame();
            this.r18c2.Name = "r18c2";
            // Container child r18c2.Gtk.Container+ContainerChild
            this.btnr18c2 = new Gtk.Label();
            this.btnr18c2.Name = "btnr18c2";
            this.btnr18c2.Justify = ((Gtk.Justification)(2));
            this.r18c2.Add(this.btnr18c2);
            this.pnlLowerScore.Add(this.r18c2);
            Gtk.Table.TableChild w290 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r18c2]));
            w290.TopAttach = ((uint)(10));
            w290.BottomAttach = ((uint)(11));
            w290.LeftAttach = ((uint)(3));
            w290.RightAttach = ((uint)(4));
            w290.XOptions = ((Gtk.AttachOptions)(4));
            w290.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r18c3 = new Gtk.Frame();
            this.r18c3.Name = "r18c3";
            // Container child r18c3.Gtk.Container+ContainerChild
            this.btnr18c3 = new Gtk.Label();
            this.btnr18c3.Name = "btnr18c3";
            this.btnr18c3.Justify = ((Gtk.Justification)(2));
            this.r18c3.Add(this.btnr18c3);
            this.pnlLowerScore.Add(this.r18c3);
            Gtk.Table.TableChild w292 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r18c3]));
            w292.TopAttach = ((uint)(10));
            w292.BottomAttach = ((uint)(11));
            w292.LeftAttach = ((uint)(4));
            w292.RightAttach = ((uint)(5));
            w292.XOptions = ((Gtk.AttachOptions)(4));
            w292.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r18c4 = new Gtk.Frame();
            this.r18c4.Name = "r18c4";
            // Container child r18c4.Gtk.Container+ContainerChild
            this.btnr18c4 = new Gtk.Label();
            this.btnr18c4.Name = "btnr18c4";
            this.btnr18c4.Justify = ((Gtk.Justification)(2));
            this.r18c4.Add(this.btnr18c4);
            this.pnlLowerScore.Add(this.r18c4);
            Gtk.Table.TableChild w294 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r18c4]));
            w294.TopAttach = ((uint)(10));
            w294.BottomAttach = ((uint)(11));
            w294.LeftAttach = ((uint)(5));
            w294.RightAttach = ((uint)(6));
            w294.XOptions = ((Gtk.AttachOptions)(4));
            w294.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r18c5 = new Gtk.Frame();
            this.r18c5.Name = "r18c5";
            // Container child r18c5.Gtk.Container+ContainerChild
            this.btnr18c5 = new Gtk.Label();
            this.btnr18c5.Name = "btnr18c5";
            this.btnr18c5.Justify = ((Gtk.Justification)(2));
            this.r18c5.Add(this.btnr18c5);
            this.pnlLowerScore.Add(this.r18c5);
            Gtk.Table.TableChild w296 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r18c5]));
            w296.TopAttach = ((uint)(10));
            w296.BottomAttach = ((uint)(11));
            w296.LeftAttach = ((uint)(6));
            w296.RightAttach = ((uint)(7));
            w296.XOptions = ((Gtk.AttachOptions)(4));
            w296.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r19c1 = new Gtk.Frame();
            this.r19c1.Name = "r19c1";
            // Container child r19c1.Gtk.Container+ContainerChild
            this.btnr19c1 = new Gtk.Label();
            this.btnr19c1.Name = "btnr19c1";
            this.btnr19c1.Justify = ((Gtk.Justification)(2));
            this.r19c1.Add(this.btnr19c1);
            this.pnlLowerScore.Add(this.r19c1);
            Gtk.Table.TableChild w298 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r19c1]));
            w298.TopAttach = ((uint)(11));
            w298.BottomAttach = ((uint)(12));
            w298.LeftAttach = ((uint)(2));
            w298.RightAttach = ((uint)(3));
            w298.XOptions = ((Gtk.AttachOptions)(4));
            w298.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r19c2 = new Gtk.Frame();
            this.r19c2.Name = "r19c2";
            // Container child r19c2.Gtk.Container+ContainerChild
            this.btnr19c2 = new Gtk.Label();
            this.btnr19c2.Name = "btnr19c2";
            this.btnr19c2.Justify = ((Gtk.Justification)(2));
            this.r19c2.Add(this.btnr19c2);
            this.pnlLowerScore.Add(this.r19c2);
            Gtk.Table.TableChild w300 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r19c2]));
            w300.TopAttach = ((uint)(11));
            w300.BottomAttach = ((uint)(12));
            w300.LeftAttach = ((uint)(3));
            w300.RightAttach = ((uint)(4));
            w300.XOptions = ((Gtk.AttachOptions)(4));
            w300.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r19c3 = new Gtk.Frame();
            this.r19c3.Name = "r19c3";
            // Container child r19c3.Gtk.Container+ContainerChild
            this.btnr19c3 = new Gtk.Label();
            this.btnr19c3.Name = "btnr19c3";
            this.btnr19c3.Justify = ((Gtk.Justification)(2));
            this.r19c3.Add(this.btnr19c3);
            this.pnlLowerScore.Add(this.r19c3);
            Gtk.Table.TableChild w302 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r19c3]));
            w302.TopAttach = ((uint)(11));
            w302.BottomAttach = ((uint)(12));
            w302.LeftAttach = ((uint)(4));
            w302.RightAttach = ((uint)(5));
            w302.XOptions = ((Gtk.AttachOptions)(4));
            w302.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r19c4 = new Gtk.Frame();
            this.r19c4.Name = "r19c4";
            // Container child r19c4.Gtk.Container+ContainerChild
            this.btnr19c4 = new Gtk.Label();
            this.btnr19c4.Name = "btnr19c4";
            this.btnr19c4.Justify = ((Gtk.Justification)(2));
            this.r19c4.Add(this.btnr19c4);
            this.pnlLowerScore.Add(this.r19c4);
            Gtk.Table.TableChild w304 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r19c4]));
            w304.TopAttach = ((uint)(11));
            w304.BottomAttach = ((uint)(12));
            w304.LeftAttach = ((uint)(5));
            w304.RightAttach = ((uint)(6));
            w304.XOptions = ((Gtk.AttachOptions)(4));
            w304.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r19c5 = new Gtk.Frame();
            this.r19c5.Name = "r19c5";
            // Container child r19c5.Gtk.Container+ContainerChild
            this.btnr19c5 = new Gtk.Label();
            this.btnr19c5.Name = "btnr19c5";
            this.btnr19c5.Justify = ((Gtk.Justification)(2));
            this.r19c5.Add(this.btnr19c5);
            this.pnlLowerScore.Add(this.r19c5);
            Gtk.Table.TableChild w306 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r19c5]));
            w306.TopAttach = ((uint)(11));
            w306.BottomAttach = ((uint)(12));
            w306.LeftAttach = ((uint)(6));
            w306.RightAttach = ((uint)(7));
            w306.XOptions = ((Gtk.AttachOptions)(4));
            w306.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r9c1 = new Gtk.Frame();
            this.r9c1.Name = "r9c1";
            // Container child r9c1.Gtk.Container+ContainerChild
            this.btnr9c1 = new Gtk.Button();
            this.btnr9c1.WidthRequest = 30;
            this.btnr9c1.HeightRequest = 27;
            this.btnr9c1.CanFocus = true;
            this.btnr9c1.Name = "btnr9c1";
            this.btnr9c1.UseUnderline = true;
            this.btnr9c1.FocusOnClick = false;
            this.btnr9c1.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr9c1.Label = "";
            this.r9c1.Add(this.btnr9c1);
            this.pnlLowerScore.Add(this.r9c1);
            Gtk.Table.TableChild w308 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r9c1]));
            w308.TopAttach = ((uint)(1));
            w308.BottomAttach = ((uint)(2));
            w308.LeftAttach = ((uint)(2));
            w308.RightAttach = ((uint)(3));
            w308.XOptions = ((Gtk.AttachOptions)(4));
            w308.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r9c2 = new Gtk.Frame();
            this.r9c2.Name = "r9c2";
            // Container child r9c2.Gtk.Container+ContainerChild
            this.btnr9c2 = new Gtk.Button();
            this.btnr9c2.WidthRequest = 30;
            this.btnr9c2.HeightRequest = 27;
            this.btnr9c2.CanFocus = true;
            this.btnr9c2.Name = "btnr9c2";
            this.btnr9c2.UseUnderline = true;
            this.btnr9c2.FocusOnClick = false;
            this.btnr9c2.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr9c2.Label = "";
            this.r9c2.Add(this.btnr9c2);
            this.pnlLowerScore.Add(this.r9c2);
            Gtk.Table.TableChild w310 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r9c2]));
            w310.TopAttach = ((uint)(1));
            w310.BottomAttach = ((uint)(2));
            w310.LeftAttach = ((uint)(3));
            w310.RightAttach = ((uint)(4));
            w310.XOptions = ((Gtk.AttachOptions)(4));
            w310.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r9c3 = new Gtk.Frame();
            this.r9c3.Name = "r9c3";
            // Container child r9c3.Gtk.Container+ContainerChild
            this.btnr9c3 = new Gtk.Button();
            this.btnr9c3.WidthRequest = 30;
            this.btnr9c3.HeightRequest = 27;
            this.btnr9c3.CanFocus = true;
            this.btnr9c3.Name = "btnr9c3";
            this.btnr9c3.UseUnderline = true;
            this.btnr9c3.FocusOnClick = false;
            this.btnr9c3.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr9c3.Label = "";
            this.r9c3.Add(this.btnr9c3);
            this.pnlLowerScore.Add(this.r9c3);
            Gtk.Table.TableChild w312 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r9c3]));
            w312.TopAttach = ((uint)(1));
            w312.BottomAttach = ((uint)(2));
            w312.LeftAttach = ((uint)(4));
            w312.RightAttach = ((uint)(5));
            w312.XOptions = ((Gtk.AttachOptions)(4));
            w312.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r9c4 = new Gtk.Frame();
            this.r9c4.Name = "r9c4";
            // Container child r9c4.Gtk.Container+ContainerChild
            this.btnr9c4 = new Gtk.Button();
            this.btnr9c4.WidthRequest = 30;
            this.btnr9c4.HeightRequest = 27;
            this.btnr9c4.CanFocus = true;
            this.btnr9c4.Name = "btnr9c4";
            this.btnr9c4.UseUnderline = true;
            this.btnr9c4.FocusOnClick = false;
            this.btnr9c4.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr9c4.Label = "";
            this.r9c4.Add(this.btnr9c4);
            this.pnlLowerScore.Add(this.r9c4);
            Gtk.Table.TableChild w314 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r9c4]));
            w314.TopAttach = ((uint)(1));
            w314.BottomAttach = ((uint)(2));
            w314.LeftAttach = ((uint)(5));
            w314.RightAttach = ((uint)(6));
            w314.XOptions = ((Gtk.AttachOptions)(4));
            w314.YOptions = ((Gtk.AttachOptions)(4));
            // Container child pnlLowerScore.Gtk.Table+TableChild
            this.r9c5 = new Gtk.Frame();
            this.r9c5.Name = "r9c5";
            // Container child r9c5.Gtk.Container+ContainerChild
            this.btnr9c5 = new Gtk.Button();
            this.btnr9c5.WidthRequest = 30;
            this.btnr9c5.HeightRequest = 27;
            this.btnr9c5.CanFocus = true;
            this.btnr9c5.Name = "btnr9c5";
            this.btnr9c5.UseUnderline = true;
            this.btnr9c5.FocusOnClick = false;
            this.btnr9c5.Relief = ((Gtk.ReliefStyle)(2));
            this.btnr9c5.Label = "";
            this.r9c5.Add(this.btnr9c5);
            this.pnlLowerScore.Add(this.r9c5);
            Gtk.Table.TableChild w316 = ((Gtk.Table.TableChild)(this.pnlLowerScore[this.r9c5]));
            w316.TopAttach = ((uint)(1));
            w316.BottomAttach = ((uint)(2));
            w316.LeftAttach = ((uint)(6));
            w316.RightAttach = ((uint)(7));
            w316.XOptions = ((Gtk.AttachOptions)(4));
            w316.YOptions = ((Gtk.AttachOptions)(4));
            this.pnlopps2.Add(this.pnlLowerScore);
            this.vbox4.Add(this.pnlopps2);
            Gtk.Box.BoxChild w318 = ((Gtk.Box.BoxChild)(this.vbox4[this.pnlopps2]));
            w318.Position = 2;
            w318.Expand = false;
            w318.Fill = false;
            this.frame5.Add(this.vbox4);
            this.hbox1.Add(this.frame5);
            Gtk.Box.BoxChild w320 = ((Gtk.Box.BoxChild)(this.hbox1[this.frame5]));
            w320.Position = 2;
            w320.Expand = false;
            w320.Fill = false;
            // Container child hbox1.Gtk.Box+BoxChild
            this.frame3 = new Gtk.Frame();
            this.frame3.Name = "frame3";
            this.frame3.ShadowType = ((Gtk.ShadowType)(0));
            // Container child frame3.Gtk.Container+ContainerChild
            this.GtkAlignment10 = new Gtk.Alignment(0F, 0F, 1F, 1F);
            this.GtkAlignment10.Name = "GtkAlignment10";
            this.GtkAlignment10.LeftPadding = ((uint)(12));
            // Container child GtkAlignment10.Gtk.Container+ContainerChild
            this.vbox1 = new Gtk.VBox();
            this.vbox1.WidthRequest = 235;
            this.vbox1.Name = "vbox1";
            this.vbox1.Spacing = 6;
            // Container child vbox1.Gtk.Box+BoxChild
            this.frame145 = new Gtk.Frame();
            this.frame145.Name = "frame145";
            // Container child frame145.Gtk.Container+ContainerChild
            this.vbox5 = new Gtk.VBox();
            this.vbox5.WidthRequest = 205;
            this.vbox5.Name = "vbox5";
            this.vbox5.BorderWidth = ((uint)(2));
            // Container child vbox5.Gtk.Box+BoxChild
            this.label1 = new Gtk.Label();
            this.label1.Name = "label1";
            this.label1.LabelProp = "<b>Players Name</b>";
            this.label1.UseMarkup = true;
            this.vbox5.Add(this.label1);
            Gtk.Box.BoxChild w321 = ((Gtk.Box.BoxChild)(this.vbox5[this.label1]));
            w321.Position = 0;
            w321.Expand = false;
            w321.Fill = false;
            w321.Padding = ((uint)(4));
            // Container child vbox5.Gtk.Box+BoxChild
            this.alignment2 = new Gtk.Alignment(0.5F, 0.5F, 1F, 1F);
            this.alignment2.Name = "alignment2";
            this.alignment2.LeftPadding = ((uint)(10));
            this.alignment2.RightPadding = ((uint)(10));
            // Container child alignment2.Gtk.Container+ContainerChild
            this.txtPlayerName = new Gtk.Entry();
            this.txtPlayerName.Sensitive = false;
            this.txtPlayerName.CanFocus = true;
            this.txtPlayerName.Name = "txtPlayerName";
            this.txtPlayerName.Text = Mono.Unix.Catalog.GetString("New Player");
            this.txtPlayerName.IsEditable = true;
            this.txtPlayerName.InvisibleChar = '●';
            this.alignment2.Add(this.txtPlayerName);
            this.vbox5.Add(this.alignment2);
            Gtk.Box.BoxChild w323 = ((Gtk.Box.BoxChild)(this.vbox5[this.alignment2]));
            w323.Position = 1;
            w323.Expand = false;
            w323.Fill = false;
            w323.Padding = ((uint)(2));
            // Container child vbox5.Gtk.Box+BoxChild
            this.tblDice = new Gtk.Table(((uint)(5)), ((uint)(2)), false);
            this.tblDice.Name = "tblDice";
            this.tblDice.RowSpacing = ((uint)(6));
            this.tblDice.ColumnSpacing = ((uint)(2));
            // Container child tblDice.Gtk.Table+TableChild
            this.cmdDice1 = new Gtk.Button();
            this.cmdDice1.CanFocus = true;
            this.cmdDice1.Name = "cmdDice1";
            this.cmdDice1.Relief = ((Gtk.ReliefStyle)(2));
            // Container child cmdDice1.Gtk.Container+ContainerChild
            this.Dice1 = new Gtk.Image();
            this.Dice1.Name = "Dice1";
            this.Dice1.Pixbuf = Gdk.Pixbuf.LoadFromResource("dice1.png");
            this.cmdDice1.Add(this.Dice1);
            this.cmdDice1.Label = null;
            this.tblDice.Add(this.cmdDice1);
            Gtk.Table.TableChild w325 = ((Gtk.Table.TableChild)(this.tblDice[this.cmdDice1]));
            w325.XPadding = ((uint)(10));
            w325.YPadding = ((uint)(3));
            w325.XOptions = ((Gtk.AttachOptions)(4));
            w325.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.cmdDice2 = new Gtk.Button();
            this.cmdDice2.CanFocus = true;
            this.cmdDice2.Name = "cmdDice2";
            this.cmdDice2.Relief = ((Gtk.ReliefStyle)(2));
            // Container child cmdDice2.Gtk.Container+ContainerChild
            this.Dice2 = new Gtk.Image();
            this.Dice2.Name = "Dice2";
            this.Dice2.Pixbuf = Gdk.Pixbuf.LoadFromResource("dice2.png");
            this.cmdDice2.Add(this.Dice2);
            this.cmdDice2.Label = null;
            this.tblDice.Add(this.cmdDice2);
            Gtk.Table.TableChild w327 = ((Gtk.Table.TableChild)(this.tblDice[this.cmdDice2]));
            w327.TopAttach = ((uint)(1));
            w327.BottomAttach = ((uint)(2));
            w327.XPadding = ((uint)(10));
            w327.YPadding = ((uint)(3));
            w327.XOptions = ((Gtk.AttachOptions)(4));
            w327.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.cmdDice3 = new Gtk.Button();
            this.cmdDice3.CanFocus = true;
            this.cmdDice3.Name = "cmdDice3";
            this.cmdDice3.Relief = ((Gtk.ReliefStyle)(2));
            // Container child cmdDice3.Gtk.Container+ContainerChild
            this.Dice3 = new Gtk.Image();
            this.Dice3.Name = "Dice3";
            this.Dice3.Pixbuf = Gdk.Pixbuf.LoadFromResource("dice3.png");
            this.cmdDice3.Add(this.Dice3);
            this.cmdDice3.Label = null;
            this.tblDice.Add(this.cmdDice3);
            Gtk.Table.TableChild w329 = ((Gtk.Table.TableChild)(this.tblDice[this.cmdDice3]));
            w329.TopAttach = ((uint)(2));
            w329.BottomAttach = ((uint)(3));
            w329.XPadding = ((uint)(10));
            w329.YPadding = ((uint)(3));
            w329.XOptions = ((Gtk.AttachOptions)(4));
            w329.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.cmdDice4 = new Gtk.Button();
            this.cmdDice4.CanFocus = true;
            this.cmdDice4.Name = "cmdDice4";
            this.cmdDice4.Relief = ((Gtk.ReliefStyle)(2));
            // Container child cmdDice4.Gtk.Container+ContainerChild
            this.Dice4 = new Gtk.Image();
            this.Dice4.Name = "Dice4";
            this.Dice4.Pixbuf = Gdk.Pixbuf.LoadFromResource("dice4.png");
            this.cmdDice4.Add(this.Dice4);
            this.cmdDice4.Label = null;
            this.tblDice.Add(this.cmdDice4);
            Gtk.Table.TableChild w331 = ((Gtk.Table.TableChild)(this.tblDice[this.cmdDice4]));
            w331.TopAttach = ((uint)(3));
            w331.BottomAttach = ((uint)(4));
            w331.XPadding = ((uint)(10));
            w331.YPadding = ((uint)(3));
            w331.XOptions = ((Gtk.AttachOptions)(4));
            w331.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.cmdDice5 = new Gtk.Button();
            this.cmdDice5.CanFocus = true;
            this.cmdDice5.Name = "cmdDice5";
            this.cmdDice5.Relief = ((Gtk.ReliefStyle)(2));
            // Container child cmdDice5.Gtk.Container+ContainerChild
            this.Dice5 = new Gtk.Image();
            this.Dice5.Name = "Dice5";
            this.Dice5.Pixbuf = Gdk.Pixbuf.LoadFromResource("dice5.png");
            this.cmdDice5.Add(this.Dice5);
            this.cmdDice5.Label = null;
            this.tblDice.Add(this.cmdDice5);
            Gtk.Table.TableChild w333 = ((Gtk.Table.TableChild)(this.tblDice[this.cmdDice5]));
            w333.TopAttach = ((uint)(4));
            w333.BottomAttach = ((uint)(5));
            w333.XPadding = ((uint)(10));
            w333.YPadding = ((uint)(3));
            w333.XOptions = ((Gtk.AttachOptions)(4));
            w333.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.lblHold1 = new Gtk.Label();
            this.lblHold1.WidthRequest = 55;
            this.lblHold1.Name = "lblHold1";
            this.lblHold1.UseMarkup = true;
            this.tblDice.Add(this.lblHold1);
            Gtk.Table.TableChild w334 = ((Gtk.Table.TableChild)(this.tblDice[this.lblHold1]));
            w334.LeftAttach = ((uint)(1));
            w334.RightAttach = ((uint)(2));
            w334.XOptions = ((Gtk.AttachOptions)(4));
            w334.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.lblHold2 = new Gtk.Label();
            this.lblHold2.WidthRequest = 55;
            this.lblHold2.Name = "lblHold2";
            this.lblHold2.UseMarkup = true;
            this.tblDice.Add(this.lblHold2);
            Gtk.Table.TableChild w335 = ((Gtk.Table.TableChild)(this.tblDice[this.lblHold2]));
            w335.TopAttach = ((uint)(1));
            w335.BottomAttach = ((uint)(2));
            w335.LeftAttach = ((uint)(1));
            w335.RightAttach = ((uint)(2));
            w335.XOptions = ((Gtk.AttachOptions)(4));
            w335.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.lblHold3 = new Gtk.Label();
            this.lblHold3.WidthRequest = 55;
            this.lblHold3.Name = "lblHold3";
            this.lblHold3.UseMarkup = true;
            this.tblDice.Add(this.lblHold3);
            Gtk.Table.TableChild w336 = ((Gtk.Table.TableChild)(this.tblDice[this.lblHold3]));
            w336.TopAttach = ((uint)(2));
            w336.BottomAttach = ((uint)(3));
            w336.LeftAttach = ((uint)(1));
            w336.RightAttach = ((uint)(2));
            w336.XOptions = ((Gtk.AttachOptions)(4));
            w336.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.lblHold4 = new Gtk.Label();
            this.lblHold4.WidthRequest = 55;
            this.lblHold4.Name = "lblHold4";
            this.lblHold4.UseMarkup = true;
            this.tblDice.Add(this.lblHold4);
            Gtk.Table.TableChild w337 = ((Gtk.Table.TableChild)(this.tblDice[this.lblHold4]));
            w337.TopAttach = ((uint)(3));
            w337.BottomAttach = ((uint)(4));
            w337.LeftAttach = ((uint)(1));
            w337.RightAttach = ((uint)(2));
            w337.XOptions = ((Gtk.AttachOptions)(4));
            w337.YOptions = ((Gtk.AttachOptions)(4));
            // Container child tblDice.Gtk.Table+TableChild
            this.lblHold5 = new Gtk.Label();
            this.lblHold5.WidthRequest = 55;
            this.lblHold5.Name = "lblHold5";
            this.lblHold5.UseMarkup = true;
            this.tblDice.Add(this.lblHold5);
            Gtk.Table.TableChild w338 = ((Gtk.Table.TableChild)(this.tblDice[this.lblHold5]));
            w338.TopAttach = ((uint)(4));
            w338.BottomAttach = ((uint)(5));
            w338.LeftAttach = ((uint)(1));
            w338.RightAttach = ((uint)(2));
            w338.XOptions = ((Gtk.AttachOptions)(4));
            w338.YOptions = ((Gtk.AttachOptions)(4));
            this.vbox5.Add(this.tblDice);
            Gtk.Box.BoxChild w339 = ((Gtk.Box.BoxChild)(this.vbox5[this.tblDice]));
            w339.Position = 2;
            w339.Expand = false;
            w339.Fill = false;
            // Container child vbox5.Gtk.Box+BoxChild
            this.hbuttonbox1 = new Gtk.HButtonBox();
            this.hbuttonbox1.Name = "hbuttonbox1";
            // Container child hbuttonbox1.Gtk.ButtonBox+ButtonBoxChild
            this.btnRoll = new Gtk.Button();
            this.btnRoll.CanFocus = true;
            this.btnRoll.Name = "btnRoll";
            this.btnRoll.UseUnderline = true;
            this.btnRoll.Label = Mono.Unix.Catalog.GetString("Roll");
            this.hbuttonbox1.Add(this.btnRoll);
            Gtk.ButtonBox.ButtonBoxChild w340 = ((Gtk.ButtonBox.ButtonBoxChild)(this.hbuttonbox1[this.btnRoll]));
            w340.Expand = false;
            w340.Fill = false;
            this.vbox5.Add(this.hbuttonbox1);
            Gtk.Box.BoxChild w341 = ((Gtk.Box.BoxChild)(this.vbox5[this.hbuttonbox1]));
            w341.Position = 3;
            w341.Expand = false;
            w341.Fill = false;
            w341.Padding = ((uint)(5));
            // Container child vbox5.Gtk.Box+BoxChild
            this.hbox2 = new Gtk.HBox();
            this.hbox2.Name = "hbox2";
            this.hbox2.Homogeneous = true;
            // Container child hbox2.Gtk.Box+BoxChild
            this.label2 = new Gtk.Label();
            this.label2.WidthRequest = 90;
            this.label2.Name = "label2";
            this.label2.Xalign = 1F;
            this.label2.Yalign = 0.66F;
            this.label2.LabelProp = "Roll #";
            this.hbox2.Add(this.label2);
            Gtk.Box.BoxChild w342 = ((Gtk.Box.BoxChild)(this.hbox2[this.label2]));
            w342.Position = 0;
            w342.Expand = false;
            w342.Fill = false;
            // Container child hbox2.Gtk.Box+BoxChild
            this.lblRollNumber = new Gtk.Label();
            this.lblRollNumber.WidthRequest = 71;
            this.lblRollNumber.Name = "lblRollNumber";
            this.lblRollNumber.Xalign = 0.1F;
            this.lblRollNumber.LabelProp = "0";
            this.hbox2.Add(this.lblRollNumber);
            Gtk.Box.BoxChild w343 = ((Gtk.Box.BoxChild)(this.hbox2[this.lblRollNumber]));
            w343.Position = 1;
            w343.Expand = false;
            w343.Fill = false;
            this.vbox5.Add(this.hbox2);
            Gtk.Box.BoxChild w344 = ((Gtk.Box.BoxChild)(this.vbox5[this.hbox2]));
            w344.Position = 4;
            w344.Expand = false;
            w344.Fill = false;
            this.frame145.Add(this.vbox5);
            this.vbox1.Add(this.frame145);
            Gtk.Box.BoxChild w346 = ((Gtk.Box.BoxChild)(this.vbox1[this.frame145]));
            w346.Position = 0;
            w346.Expand = false;
            w346.Fill = false;
            // Container child vbox1.Gtk.Box+BoxChild
            this.frame48 = new Gtk.Frame();
            this.frame48.Name = "frame48";
            this.frame48.ShadowType = ((Gtk.ShadowType)(0));
            // Container child frame48.Gtk.Container+ContainerChild
            this.GtkAlignment11 = new Gtk.Alignment(0F, 0F, 1F, 1F);
            this.GtkAlignment11.Name = "GtkAlignment11";
            // Container child GtkAlignment11.Gtk.Container+ContainerChild
            this.GtkScrolledWindow = new Gtk.ScrolledWindow();
            this.GtkScrolledWindow.Name = "GtkScrolledWindow";
            this.GtkScrolledWindow.ShadowType = ((Gtk.ShadowType)(1));
            // Container child GtkScrolledWindow.Gtk.Container+ContainerChild
            this.gvResults = new Gtk.TreeView();
            this.gvResults.CanFocus = true;
            this.gvResults.Name = "gvResults";
            this.gvResults.EnableSearch = false;
            this.gvResults.RulesHint = true;
            this.GtkScrolledWindow.Add(this.gvResults);
            this.GtkAlignment11.Add(this.GtkScrolledWindow);
            this.frame48.Add(this.GtkAlignment11);
            this.vbox1.Add(this.frame48);
            Gtk.Box.BoxChild w350 = ((Gtk.Box.BoxChild)(this.vbox1[this.frame48]));
            w350.Position = 1;
            this.GtkAlignment10.Add(this.vbox1);
            this.frame3.Add(this.GtkAlignment10);
            this.hbox1.Add(this.frame3);
            Gtk.Box.BoxChild w353 = ((Gtk.Box.BoxChild)(this.hbox1[this.frame3]));
            w353.Position = 3;
            w353.Expand = false;
            w353.Fill = false;
            this.vbox2.Add(this.hbox1);
            Gtk.Box.BoxChild w354 = ((Gtk.Box.BoxChild)(this.vbox2[this.hbox1]));
            w354.Position = 0;
            w354.Expand = false;
            w354.Fill = false;
            this.alignment1.Add(this.vbox2);
            this.hbox3.Add(this.alignment1);
            Gtk.Box.BoxChild w356 = ((Gtk.Box.BoxChild)(this.hbox3[this.alignment1]));
            w356.Position = 0;
            w356.Expand = false;
            w356.Fill = false;
            this.Add(this.hbox3);
            if ((this.Child != null)) {
                this.Child.ShowAll();
            }
            this.Show();
            this.DeleteEvent += new Gtk.DeleteEventHandler(this.OnDeleteEvent);
            this.NewGame.Activated += new System.EventHandler(this.OnNewActivated);
            this.open.Activated += new System.EventHandler(this.OnOpenActivated);
            this.save.Activated += new System.EventHandler(this.OnSaveActivated);
            this.About.Activated += new System.EventHandler(this.OnAboutActivated);
            this.quit.Activated += new System.EventHandler(this.OnQuitActivated);
            this.undo.Activated += new System.EventHandler(this.OnUndoActivated);
            this.redo.Activated += new System.EventHandler(this.OnRedoActivated);
            this.btnr5c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr5c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr5c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr5c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr5c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr5c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr5c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr5c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr5c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr5c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr5c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr5c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr5c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr5c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr5c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr4c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr4c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr4c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr4c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr4c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr4c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr4c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr4c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr4c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr4c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr4c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr4c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr4c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr4c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr4c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr3c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr3c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr3c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr3c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr3c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr3c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr3c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr3c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr3c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr3c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr3c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr3c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr3c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr3c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr3c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr2c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr2c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr2c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr2c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr2c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr2c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr2c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr2c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr2c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr2c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr2c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr2c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr2c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr2c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr2c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr1c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr1c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr1c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr1c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr1c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr1c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr1c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr1c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr1c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr1c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr1c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr1c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr1c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr1c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr1c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr0c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr0c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr0c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr0c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr0c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr0c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr0c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr0c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr0c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr0c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr0c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr0c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr0c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr0c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr0c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr9c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr9c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr9c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr9c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr9c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr9c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr9c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr9c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr9c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr9c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr9c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr9c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr9c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr9c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr9c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr16c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr16c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr16c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr16c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr16c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr16c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr16c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr16c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr16c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr16c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr16c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr16c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr16c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr16c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr16c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr15c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr15c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr15c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr15c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr15c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr15c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr15c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr15c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr15c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr15c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr15c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr15c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr15c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr15c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr15c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr14c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr14c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr14c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr14c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr14c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr14c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr14c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr14c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr14c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr14c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr14c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr14c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr14c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr14c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr14c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr13c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr13c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr13c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr13c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr13c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr13c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr13c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr13c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr13c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr13c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr13c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr13c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr13c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr13c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr13c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr12c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr12c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr12c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr12c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr12c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr12c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr12c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr12c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr12c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr12c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr12c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr12c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr12c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr12c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr12c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr11c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr11c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr11c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr11c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr11c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr11c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr11c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr11c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr11c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr11c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr11c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr11c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr11c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr11c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr11c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr10c5.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr10c5.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr10c5.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr10c4.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr10c4.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr10c4.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr10c3.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr10c3.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr10c3.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr10c2.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr10c2.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr10c2.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.btnr10c1.Entered += new System.EventHandler(this.ScoreCard_MouseHover);
            this.btnr10c1.Left += new System.EventHandler(this.ScoreCard_MouseLeave);
            this.btnr10c1.Clicked += new System.EventHandler(this.ScoreCard_Click);
            this.cmdDice5.Entered += new System.EventHandler(this.OnCmdDice1Entered);
            this.cmdDice5.Clicked += new System.EventHandler(this.OnCmdDice5Clicked);
            this.cmdDice4.Entered += new System.EventHandler(this.OnCmdDice1Entered);
            this.cmdDice4.Clicked += new System.EventHandler(this.OnCmdDice4Clicked);
            this.cmdDice3.Entered += new System.EventHandler(this.OnCmdDice1Entered);
            this.cmdDice3.Clicked += new System.EventHandler(this.OnCmdDice3Clicked);
            this.cmdDice2.Clicked += new System.EventHandler(this.OnCmdDice2Clicked);
            this.cmdDice2.Entered += new System.EventHandler(this.OnCmdDice1Entered);
            this.cmdDice1.Entered += new System.EventHandler(this.OnCmdDice1Entered);
            this.cmdDice1.Clicked += new System.EventHandler(this.OnCmdDice1Clicked);
            this.btnRoll.Clicked += new System.EventHandler(this.OnBtnRollClicked);
        }
    }
}
